UPDATE `engine4_payment_gateways` SET `default_icon` = '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><g clip-path="url(#clip0_2824_18848)"><path d="" fill="black"/></g><defs><clipPath id="clip0_2824_18848"><rect width="24" height="24" fill="white"/></clipPath></defs></svg>' WHERE `engine4_payment_gateways`.`plugin` = 'Payment_Plugin_Gateway_Coinpayment';