<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

 return array (
  'package' => array(
    'type' => 'module',
    'name' => 'coinpayments',
    'version' => '8.1.0',
    'path' => 'application/modules/Coinpayments',
    'repository' => 'socialengine.com',
    'title' => 'Cryptocurrency Payment Gateway Plugin',
    'description' => 'Cryptocurrency Payment Gateway Plugin',
    'author' => '<a href="https://socialengine.com/" style="text-decoration:underline;" target="_blank">SocialEngine</a>',
    'thumb' => 'application/modules/Coinpayments/externals/images/thumb.png',
    'dependencies' => array(
      array(
        'type' => 'module',
        'name' => 'core',
        'minVersion' => '8.0.0',
      ),
    ),
    'actions' => array(
      'install',
      'upgrade',
      'refresh',
      'enable',
      'disable',
    ),
    'callback' => array(
      'path' => 'application/modules/Coinpayments/settings/install.php',
      'class' => 'Coinpayments_Installer',
    ),
    'directories' => array(
      'application/modules/Coinpayments',
    ),
    'files' => array(
      'application/languages/en/coinpayments.csv',
    ),
  ),
);
