<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Coinpayments_Api_Core extends Core_Api_Abstract 
{

    function crypto(){
        
        return array (
            'BTC' => 'Bitcoin',
            'BTC.BEP20' => 'Bitcoin/BTCB Token (BSC Chain)',
            'BTC.LN' => 'Bitcoin (Lightning Network)',
            'BCH' => 'Bitcoin Cash',
            'BCH.BEP20' => 'Bitcoin Cash Token (BSC Chain)',
            'LTC' => 'Litecoin',
            'LTC.BEP20' => 'Litecoin Token (BSC Chain)',
            'VLX' => 'Velas (EVM)',
            'VLX.Native' => 'Velas (Native)',
            '0xETD' => '0xETH Diamond',
            '3DB' => '3D BlockChain Token',
            '5KM' => '5KM',
            777 => 'BINGO Entertainment',
            '7E' => '7ELEVEN',
            '8BT' => '8 Circuit Studios Token',
            '9TK' => '9TOKEN',
            'A' => 'Alpha',
            'A2A' => 'A2A Token',
            'AAA' => 'App Alliance Association',
            'AAVE' => 'Aave Token',
            'AB' => 'ArgotBit',
            'ABB' => 'ArmBlockchainBank',
            'ABC' => 'ABC - Anti Bureaucracy Coin',
            'ABCS' => 'AbacasXchange [Abacas] Token',
            'ABE' => 'ABE',
            'ABL' => 'Airbloc',
            'ABTN' => 'ARBITANO',
            'ACE' => 'Ace Wins',
            'ACTP' => 'Archetypal Network',
            'ACTX' => 'ARCHETYPALX',
            'ADA.BEP20' => 'Cardano Token (BSC Chain)',
            'ADB' => 'AdBank',
            'ADC1' => 'Artdotcoin V1',
            'ADI' => 'Aditus',
            'ADP' => 'ADPOWER',
            'ADS' => 'ADSCASH',
            'ADSVC' => 'ADs Venture',
            'ADVC' => 'advertisingcoin',
            'AE' => 'Aeternity',
            'AED' => 'United Arab Emirates Dirham',
            'AEDex' => 'NEEX UAE Dirham',
            'AENS' => 'AEN Smart Token',
            'AET' => 'AeternumToken',
            'AET2' => 'AeroToken',
            'aETHc' => 'Ankr ETH2 Reward Bearing Certificate',
            'AFC' => 'Apiary Fund Coin',
            'AFDLT' => 'AfroDex Labs Token',
            'AfroX' => 'AfroDex',
            'AFTK' => 'AFTK Token',
            'AGC' => 'Apuri Gaming Coin',
            'Agem' => 'AlphaGem',
            'AGI' => 'SingularityNET Token',
            'AGN' => 'Agricoin',
            'AGRE' => 'Agrevo Coin',
            'AGRI' => 'AgriChain',
            'AGRI2' => 'AgriChain Utility Token',
            'AGT' => 'AGATE',
            'AI' => 'PolyAi',
            'AiBe' => 'AiBe',
            'AIC' => 'AICRYPTO',
            'AIC2' => 'AICRYPTO',
            'AID' => 'AidCoin',
            'AIDOC' => 'AI Doctor',
            'AIGC' => 'AI Gaming Coin',
            'AIGO' => 'AIGO Payment',
            'AIRx' => 'Aircoins',
            'AIT' => 'AIT',
            'AKA' => 'AKA Coin',
            'AKITA' => 'Akita Inu',
            'AKRO' => 'Akropolis',
            'AKYE' => 'Oyster Akoya',
            'AKYU' => 'Akyumen',
            'ALB' => 'Alphabee',
            'ALC' => 'AladdinCoin',
            'ALF' => 'Aeternum Libertarian Foundation',
            'ALGOR' => 'Algorblock Coin',
            'ALI' => 'AiLink Token',
            'ALP' => 'ALPHAPROTOCOL',
            'ALPHA' => 'Alpha',
            'ALPHA2' => 'AlphaToken',
            'ALTX' => 'Alttex',
            'ALX' => 'ALX',
            'AMA' => 'AmaCoin',
            'AMB' => 'Amber Token',
            'AMBA' => 'Ambazonia Coin',
            'AMBT' => 'Ambit token',
            'AMIS' => 'AMIS',
            'AMN' => 'Amon',
            'AMON' => 'AmonD',
            'AMP' => 'Amp',
            'AMPL' => 'Ampleforth',
            'AMR' => 'AMMBR',
            'AMSC' => 'AmethystCoin',
            'AMT' => 'Arab Money',
            'ANGEL' => 'AngelToken',
            'ANON' => 'Anon',
            'ANON2' => 'ANONYMOUS',
            'anyDAI' => 'Dai Stablecoin',
            'anyETH.BEP20' => 'ANY Ethereum (BSC Chain)',
            'anyUSDC' => 'USDC',
            'anyUSDT' => 'Tether USD',
            'AOA' => 'Angolan Kwanza',
            'AOA.ERC20' => 'Aurora',
            'APE' => 'ApeCoin',
            'API3' => 'API3',
            'APIS' => 'APIS',
            'APM' => 'APM Coin',
            'APO' => 'APO Coin',
            'APOD' => 'Airpod token',
            'APPC' => 'AppCoins',
            'APPU' => 'Apputoken',
            'APX' => 'APEX',
            'AQU' => 'Aquarius Token',
            'AR2' => 'Arcoin',
            'ARAW' => 'ARAW',
            'ARB.ERC20' => 'ARBITRAGE',
            'ARBIT' => 'ARBITRAGE',
            'ARC' => 'Aracle',
            'ARCG' => 'Arch Crypton Game',
            'ARCONA' => 'Arcona Distribution Contract',
            'ARGC' => 'ArgosCoins',
            'ARGP' => 'ArgenPeso',
            'ARM' => 'Aeroneum',
            'ARN' => 'Aeron',
            'ARP' => 'ARP',
            'ARPA' => 'ARPA Token',
            'ARS' => 'Argentine Peso',
            'ARTH' => 'ARTH',
            'ARV.BEP20' => 'ARIVA (BSC Chain)',
            'ASK2' => 'Ask All People Token',
            'ASM' => 'AsmChain',
            'AST.ERC20' => 'AirSwap Token (ERC20)',
            'AT' => 'AutoToken',
            'ATEM' => 'ATEM',
            'ATEM.BEP20' => 'ATEM (BSC Chain)',
            'ATK' => 'Auto Token',
            'ATL' => 'ATLANT Token',
            'ATMI' => 'Atonomi',
            'ATOC' => 'ATOCoin',
            'ATOM' => 'ATOMX',
            'ATOM.BEP20' => 'Cosmos Token (BSC Chain)',
            'Atp' => 'Atp',
            'Auction' => 'Bounce Token',
            'AUDIO.ERC20' => 'Audius (ERC20)',
            'AUPC' => 'Authpaper Coin',
            'AUSC' => 'AUSCCHAIN',
            'AVEX' => 'Aevolve',
            'AVINOC' => 'AVINOC Token',
            'AVT' => 'Advertising Token',
            'AVT2' => 'Aventus',
            'AVVP' => 'Andrey Voronkov Ventures Promo',
            'AWC' => 'Atomic Wallet Token',
            'AWE' => 'AWE Shares',
            'AXEL' => 'AXEL-AIRDROP',
            'AXPR' => 'aXpire',
            'AXS' => 'Axie Infinity Shard',
            'AXTR' => 'Axetrade Coin',
            'AZ' => 'Azbit',
            'AZN' => 'Azerbaijani Manat',
            'B21' => 'B21 Token',
            'B2BX' => 'B2BX',
            'B2C' => 'B2ANDcoin',
            'B2X' => 'BtcSegwit2X',
            'BAAS' => 'BaaSid',
            'BAC' => 'BlockAsia Coin',
            'BANG' => 'The Big Bang',
            'BAR' => 'Titanium BAR Token',
            'BARG' => 'Bitbarg',
            'BART' => 'Barnes Token',
            'BASE' => 'Equitybase',
            'BAT' => 'Basic Attention Token',
            'BAZT' => 'Baz Token',
            'BAZT2' => 'Baz Token',
            'BBC' => 'Bob Coin',
            'BBC2' => 'BBC TOKEN',
            'BBI' => 'Beluga Banking Infrastructure Token',
            'BBK' => 'BrickblockToken',
            'BBK2' => 'BrickblockToken',
            'BBR' => 'Best Biology Resources',
            'BBTC' => 'Binance Wrapped BTC',
            'BC' => 'BoomstarterCoin',
            'BC2' => '"Bullion Coin" Bullion Troy Grain Coin',
            'BCASH' => 'Bankcoin',
            'BCD2' => 'Bitcoin Diamond Token',
            'BCDT' => 'Blockchain Certified Data Token',
            'BCMC1' => 'BeforeCoinMarketCap',
            'BCMG' => 'Blockchain Media Group',
            'BCO' => 'BananaCoin Extended',
            'BCP' => 'bitcoinplatinums',
            'BCP2' => 'BlockchainPoland',
            'BCPT' => 'BLOCKMASON CREDIT PROTOCOL TOKEN',
            'BCT' => 'BCT Token',
            'BCV' => 'BitCapitalVendorToken',
            'BCZ' => 'Betcruisez',
            'BDCC' => 'BDCC COIN',
            'BDG' => 'BitDegree Token',
            'BDOT' => 'Binance Wrapped DOT',
            'BEAT' => 'BEAT',
            'BEAUTY' => 'Beauty Coin',
            'BEAUTY2' => 'Beauty Coin',
            'BEC' => 'BeautyChain',
            'BEC7' => 'BEC 700',
            'BECX' => 'BEACONIEC',
            'BEE' => 'Bee Token',
            'BEENG' => 'BEENG Token',
            'BEG' => 'BEG',
            'BELA' => 'Bela',
            'BER' => 'Bermuda triangle',
            'BERM' => 'Berm Protocol Token',
            'BEST' => 'Bitpanda Ecosystem Token',
            'BETHER' => 'Bethereum',
            'BETRA' => 'Betra coin',
            'BETRA2' => 'Betra coin',
            'Bez' => 'Bezop',
            'BFB' => 'Bi Fu Bao',
            'BFDT' => 'BFDToken',
            'BFT' => 'BF Token',
            'BGENE' => 'Bitcoin Gene',
            'BGF' => 'Biograffi',
            'BGN' => 'Bulgarian Lev',
            'BGR' => 'Bitgram',
            'BHIG' => 'BuckHathToken',
            'BHPC' => 'BHPCash',
            'BIB' => 'Bi ecology Token',
            'BIC' => 'BITFINCOIN',
            'BICITY.BEP20' => 'BiCity AI Projects (BSC Chain)',
            'BIGO' => 'BIGO Token',
            'BIL' => 'BitLand',
            'BIM' => 'Bimcoin',
            'BIN' => 'Buildin',
            'BIO' => 'BioCrypt',
            'BIRC' => 'Business Interactive Reward Coin',
            'BIT' => 'BitRewards Token',
            'BITCAR' => 'BitCar',
            'BITE' => 'Bitcoin EOS',
            'BITOX' => 'BitoxTokens',
            'BITRON' => 'Bitcoin TRONIX',
            'BITTO' => 'BITTO',
            'BITTO.Old' => 'BITTO',
            'BITX' => 'BitScreenerToken',
            'BITX2' => 'BITIFEX',
            'BIZ' => 'BIZAIN Token',
            'BK' => 'Blockkoin',
            'BK2' => 'Blockkoin',
            'BKC' => 'Bankcoin Cash',
            'BKS' => 'BKS',
            'BKX' => '"BANKEX" project utility token',
            'BKY' => 'BLUEKEY',
            'BLB' => 'BillionByte',
            'BLISS' => 'Bliss Exchange Token',
            'BLK2' => 'BLKtoken',
            'BLZ' => 'Bluzelle Token',
            'BM' => 'BITCOMO',
            'BMAX' => 'BitcoinMax',
            'BMC' => 'Blackmoon Crypto Token',
            'BMEX' => 'HITMEX Token',
            'BMT' => 'BitMinutes',
            'BNB.BSC' => 'BNB Coin (BSC Chain)',
            'BNB.ERC20' => 'BNB Coin (ERC-20)',
            'BNB2' => 'BNB Coin',
            'BNEX' => 'HashingAds',
            'BNFT' => 'Benefits Coin',
            'BNI' => 'Betnomi',
            'BNI.Old' => 'Betnomi (Old)',
            'BNI.Old2' => 'Betnomi (Old)',
            'BNK' => 'Banker Token',
            'BNOW' => 'Bluenote World Token',
            'BNT' => 'Bancor Network Token',
            'BNT2' => 'Binantex',
            'BNX' => 'BTCNEXT token',
            'BNX2' => 'Bitnordex',
            'BNX3' => 'BNX Token',
            'BOB' => 'BOB Token',
            'BOBA' => 'Boba Token',
            'BOC' => 'BingoCoin',
            'BOLD' => 'Boldman',
            'BOOTY' => 'BOOTY',
            'BOR' => 'Basement Operation Realm',
            'BOR2' => 'BitCollar',
            'BOS' => 'BOSTOKEN',
            'BOTA' => 'Adbota',
            'BOUNCY' => 'BouncyCoinToken',
            'BOUNCY2' => 'BouncyCoinToken',
            'BOX' => 'Beonbox',
            'BPT' => 'Bitpayer Token',
            'BPT2' => 'BitPumps Token',
            'BPTN' => 'BPTN',
            'BPTT' => 'Bitpunter',
            'BQQQ' => 'Bitsdaq',
            'BQQQ2' => 'BITSDAQ TOKEN',
            'BQTX' => 'BqtX Token',
            'BRD' => 'Bread Token',
            'BRDC' => 'Board Coin',
            'BRL' => 'Brazilian Real',
            'BRM' => 'BrahmaOS',
            'BRT' => 'BHIGRewardToken',
            'BRZC' => 'BreezeCoin',
            'BSC' => 'BsaiCoin',
            'BSD2' => 'BUSHIDO',
            'BSR' => 'BetShare',
            'BSTN' => 'BitStation',
            'BTAP.BEP20' => 'BTAP (BSC Chain)',
            'BTAP.ERC20' => 'BTAP (ERC20)',
            'BTB' => 'Bitibu',
            'BTCA' => 'BitAir',
            'BTCB' => 'BitcoinBrand',
            'BTCC' => 'BitcoinCrown',
            'BTCG' => 'BitcoinGalaxy',
            'BTCGW' => 'BitcoinGalaxy Warp',
            'BTCM' => 'BITCOIN MOON',
            'BTCM2' => 'BitcoinMonkey',
            'BTCONE' => 'BLOCK NETWORK',
            'BTCPLO' => 'BTCplode',
            'BTCR' => 'Bitcoin Red',
            'BTCS' => 'Bitcoin Summit',
            'BTCS2' => 'BtcSweet Coin',
            'BTCX' => 'BitText',
            'BTD' => 'Bitcoin Dollar',
            'BTG2' => 'Bullion Troy Grain',
            'BTH' => 'BITETHER',
            'BTK' => 'BitcoinToken',
            'BTL' => 'BTL',
            'BTL2' => 'Bitlle Token',
            'BTL3' => 'Bitles Token',
            'BTM' => 'Bitcoin Mart',
            'BTM2' => 'Bytom',
            'BTMC' => 'MinerCoin',
            'BTN' => 'Biztranex',
            'BTN2' => 'Bit New',
            'BTNT' => 'BitNautic Token',
            'BTO' => 'Bitron Coin',
            'BTR' => 'Bither Platform Token',
            'BTRN' => 'BTRN',
            'BTRS' => 'BitBall Treasure',
            'BTSG' => 'BitSong',
            'BTT.TRC20' => 'BitTorrent (Tron/TRC20)',
            'BTTC' => 'Bittwit Coin',
            'btz' => 'bitzon',
            'BTZ2' => 'Botz Token',
            'BUBO' => 'Bubo',
            'BUGS.BEP20' => 'Bugs Bunny Token (BSC Chain)',
            'BUL' => 'Bulleon',
            'BUL2' => 'Bulleon',
            'BUNNY' => 'BunnyToken',
            'BURP' => 'Burp',
            'BUSD' => 'Binance USD (ERC20)',
            'BUSD.BEP20' => 'BUSD Token (BSC Chain)',
            'BUSD.TRC20' => 'Binance USD (Tron/TRC20)',
            'BUT' => 'BitUP Token',
            'BVSN' => 'business value system',
            'BWX' => 'BlueWhaleToken',
            'BXA' => 'BXA',
            'BXK' => 'Bitbook Gambling',
            'BXMI' => 'Bxmi (BSC Chain)',
            'BXMI.ERC20' => 'Bitxmi (ERC20, Old Chain)',
            'BXN' => 'BlackFort Exchange Network',
            'BYCC' => 'ByteCashCoin',
            'BYN' => 'Belarusian Ruble',
            'BYTM' => 'Bytemine',
            'BZET' => 'BITZET',
            'BZX' => 'bzxcoin',
            'C4F' => 'C4F FavorCoins',
            'C8' => 'Carboneum',
            'CAF' => 'CharterCoin',
            'CAIZ' => 'CAIZCOIN',
            'CAKE.BEP20' => 'PancakeSwap Token (BSC Chain)',
            'CAMS' => 'CAMS',
            'CAN' => 'CanYaCoin',
            'CANDY' => 'CandyHCoin',
            'CANX' => 'CANX',
            'CAO' => 'CaoLiuToken',
            'CAPC' => 'CampingCoin',
            'CAPP' => 'Cappasity',
            'CAPP2' => 'CAPP Token',
            'CAS' => 'Cashaa',
            'CAST' => 'Castro Token',
            'CAV' => 'Caviar',
            'CB' => 'CBCOIN',
            'CBIT' => 'CryptoBots: Idle Token',
            'CBIX' => 'Cubrix',
            'CBN' => 'Cryptbond Network',
            'CBP' => 'CashBackPro',
            'CBR' => 'CCBrother',
            'CBS' => 'Cryptoboss',
            'CBT' => 'Chatabox Token',
            'CBT2' => 'CIBUS Token',
            'CBT3' => 'Click Bee',
            'CBTB' => 'CryptoBotsBattle',
            'CBUCKS' => 'CRYPTOBUCKS',
            'CC' => 'Coin-coin',
            'CCC' => 'ClipperCoin',
            'CCC2' => 'Coinchat Coin',
            'CCC3' => 'CriptoComunidadCoin',
            'CCCoin' => 'Car-Chain-Coin',
            'CCH' => 'Coinchase Token',
            'CCHN' => 'CChain CCHN',
            'CCIO' => 'CryptoControl',
            'CCL' => 'CyClean Token',
            'CCN' => 'CryptoCurrencyNetwork',
            'ccnext' => 'ccnextchain',
            'CCOG' => 'Clan Chain Of Global',
            'CCOS' => 'CrowdCoinage',
            'CCP' => 'CryptoCoinPay',
            'CCRB' => 'CryptoCarbon',
            'CCS' => 'Crypto Credit System Token',
            'CCT' => 'Crystal Clear Token',
            'cDAI' => 'Compound Dai',
            'CDC' => 'CryptoDuelCoin',
            'CDC2' => 'Crypto Duel Coin',
            'CDRX' => 'CDRX Token',
            'CDT' => 'CoinDash Token',
            'CEEK' => 'CEEK',
            'CELC' => 'CelCoin',
            'CELR' => 'CelerNetwork',
            'CELR2' => 'CelerToken',
            'CEN' => 'Centaure Token',
            'CEN2' => 'CEN',
            'CENNZ' => 'Centrality Token',
            'Centra' => 'Centra token',
            'CF' => 'CryptoFlowers',
            'CFI' => 'Cofoundit',
            'CGC' => 'CGCOINS',
            'CGC2' => 'Cash Global Coin',
            'CGCX' => 'CGCX Exchange Token',
            'CGW' => 'CGW',
            'CHART' => 'BetOnChart token',
            'CHC' => 'CHC TOKEN',
            'Che' => 'CheGuevara',
            'CHF' => 'Swiss Franc',
            'CHG' => 'Charg Coin',
            'CHP' => 'Poker Chips',
            'CHR' => 'Chromia',
            'CHR2' => 'Chroma',
            'CHR3' => 'Chroma',
            'CHSB' => 'SwissBorg Token',
            'CIM' => 'CIMTOKEN',
            'CIPX' => 'ColletrixToken',
            'CIT' => 'CariNet Token',
            'CITY' => 'CITY',
            'CJT' => 'ConnectJob',
            'CK' => 'CryptoKitties',
            'CKEY' => 'CryptoBNB',
            'CLB' => 'Cloudbric',
            'CLC' => 'CLC',
            'CLEAR' => 'CLEAR Token',
            'CLIN' => 'Clinicoin',
            'CLM' => 'CoinClaim',
            'CLN' => 'Colu Local Network',
            'CLO' => 'Cryptlo',
            'CLOG' => 'CLO Gold',
            'CLOUT' => 'CLOUT',
            'CLP' => 'Chilean Peso',
            'CLR' => 'ClearCoin',
            'CLV' => 'Clover',
            'CM' => 'CoinsMet',
            'CMA' => 'CoinMarketAlert',
            'CMA2' => 'CryptoMarketAdsToken',
            'CMIT' => 'COMIKETCOIN',
            'CMN' => 'Crypto Monsoon Token',
            'CMT' => 'CyberMiles Token (ERC20)',
            'CNB' => 'Coinsbit Token',
            'CNC' => 'Coinyspace',
            'CND' => 'Cindicator Token',
            'CNG' => 'CNG Casino',
            'CNHT' => 'Tether CNH (ERC20)',
            'CNHT.TRC20' => 'Tether CNH (Tron/TRC20)',
            'CNMC' => 'CNMC',
            'CNN' => 'CNN Token',
            'CNNS' => 'Crypto Neo-value Neural System',
            'CNX' => 'Cryptonex (CNX)',
            'CNY' => 'Chinese Yuan',
            'CoCo' => 'CornerCoin',
            'COFI' => 'CoinFi',
            'COI' => 'Coinnec',
            'COI2' => 'Carbon',
            'COL2' => 'Unit Protocol',
            'COM' => 'CommonsOS (ERC20)',
            'COMP' => 'Compound',
            'CONS121' => 'Onigiri',
            'COP' => 'Columbian Peso',
            'CORES' => 'Innercore',
            'COREX' => 'COREX',
            'COSM' => 'CosmoCoin',
            'COSM2' => 'CosmoCoin',
            'COTI' => 'Coti',
            'COTI2' => 'COTI Token',
            'COU' => 'Couchain',
            'COVA' => 'Covalent Token',
            'COVER' => 'Cover Protocol Governance Token',
            'CP' => 'Crow Token',
            'CPAY' => 'CPAY Token',
            'CPC' => 'CPChain',
            'CPF' => 'ChainPow Finance',
            'CPG' => 'CastlePeak Game',
            'CPIT' => 'CPITOKEN',
            'CPL' => 'Coinplace token CPL-token',
            'CPOL' => 'CryptoPolitan',
            'CPR' => 'Cipher',
            'CPROP' => 'CPROP',
            'CPT' => 'Cryptaur',
            'CPTL' => 'Capital Coin',
            'CPX' => 'Crypxie',
            'CRAFTR' => 'CraftR',
            'CRB' => 'CreditBIT',
            'CRC' => 'CR Coin',
            'CRD' => 'CreditDefi',
            'CRD2' => 'CreditDefi',
            'CRE' => 'Cybereits Token',
            'CREDO' => 'Credo Token',
            'CREO' => 'CREO COIN',
            'CRET' => 'Crypto Energy Token CRET',
            'CREV' => 'Cryptorevolution Token',
            'CRO' => 'Crowd Investor',
            'CRO2' => 'CRO',
            'CROS' => 'CROS',
            'CRPT' => 'CrypteriumToken',
            'CRT' => 'Cryptonits',
            'CRX' => 'Core',
            'CRYO' => 'CRYO',
            'CRYSTAL' => 'CrystalTokens',
            'CS' => 'CREDITS',
            'CSAT' => 'CandysAirdrop',
            'CSM' => 'Consentium Coin',
            'CSMX' => 'Consentium Plus',
            'CSR' => 'COINSERO',
            'CTAT' => 'Cryptassist',
            'CTH' => 'CATHER',
            'CTK' => 'Cryptyk Tokens',
            'CTO' => 'CotteToken',
            'CTSI' => 'Cartesi Token',
            'CTSI.BEP20' => 'Cartesi Token (BSC Chain)',
            'CTX' => 'CarTaxi',
            'CTXC' => 'Cortex Coin',
            'CUAN' => 'Kingcuan',
            'CUB' => 'Cubebit',
            'CUC' => 'Cuban Convertible Peso',
            'CUE.BEP20' => 'CUE Protocol (BSC Chain)',
            'cUSDC' => 'Compound USD Coin',
            'cV' => 'cVToken',
            'CVA' => 'Crypto Village Accelerator',
            'CVM' => 'Cavallium Coin',
            'CVP' => 'Concentrated Voting Power',
            'CVT' => 'Credo Verification Token',
            'CWN' => 'CryptoWorldNews Token',
            'CWV' => 'CWV Chain',
            'CYFM' => 'CYBERFM',
            'CYL' => 'CrystalToken',
            'CZK' => 'Czech Koruna',
            'DAAR' => 'Digital Asset Automated Revenue',
            'DAC' => 'Decentralized Accessible Content',
            'DACC' => 'Decentralized Accessible Content Chain',
            'DACC2' => 'Decentralized Accessible Content Chain',
            'DAF' => 'DAXFINEX',
            'DAG' => 'DagX Token',
            'DAG2' => 'Constellation',
            'DAI' => 'Dai (ERC20)',
            'DAI.BEP20' => 'Dai Token (BSC Chain)',
            'DAI.PRC20' => '(PoS) Dai Stablecoin (Polygon)',
            'DAI2' => 'Dai Stablecoin',
            'DAN' => 'Daneel',
            'DANK' => 'Dank Signals',
            'DANS' => 'DAN-Service coin',
            'DAP2' => 'DAPTOKEN',
            'DAPPT' => 'Dapp Token',
            'DAPPX' => 'dAppstore Token',
            'DAR' => 'Defraycoin',
            'DAR2' => 'Daric',
            'DARK' => 'DARK COIN',
            'DASH' => 'Dash',
            'DAT' => 'DAT Token',
            'DATBOI' => 'DatBoi',
            'DATG' => 'DATUM GOLD',
            'DATP' => 'Decentralized Asset Trading Platform',
            'DATx' => 'DATx',
            'DAV' => 'DAV Token',
            'DAX' => 'DAEX Token',
            'DBC.BEP20' => 'Dhabi Coin (BSC Chain)',
            'DBM' => 'D-Bank Token',
            'DC' => 'DATACHAIN',
            'DCA' => 'Decentralize Currency Assets',
            'DCA.Old' => 'DecentralizedCurrencyAssets',
            'DCAS' => 'Digital Crypto Ads',
            'DCAST' => 'Digital Crypto Ads',
            'DCC' => 'Distributed Credit Chain',
            'DCHS' => 'DochStar',
            'DCNX' => 'DCNXToken',
            'DCORP' => 'DCORP',
            'DCS' => 'DELTA CASH SYSTEMS',
            'DCS2' => 'DCS TOKEN',
            'DCTO' => 'Decentralized Crypto Token',
            'dDai' => 'Dharma Dai',
            'DEAL' => 'IPDeal',
            'DEED' => 'Deedcoin',
            'DeerEx' => 'DeerExToken',
            'DEFL' => 'Deflacoin',
            'DELTA' => 'DeltaChain Token',
            'DEN' => 'DENtoken',
            'DFR' => 'Diffract Finance',
            'DFS' => 'Digital Fantasy Sports',
            'DFS2' => 'Fantasy Sports',
            'DGB' => 'DigiByte',
            'DGC2' => 'Doge Gold Coin',
            'DGPT' => 'DigiPulse Token',
            'DGT.BEP20' => 'DGT (BSC Chain)',
            'DGTX' => 'DigitexFutures',
            'DGTX2' => 'DigitexFutures',
            'DHT' => 'Deep Health Token',
            'DIC' => 'DiamondChain',
            'DIFX' => 'DigitalFinancialExch',
            'DIGT' => 'Digitale',
            'DiGTC' => 'Digitcashcoin',
            'DIMND' => 'DIAMOND',
            'DITC' => 'Ditcoin',
            'DITC3' => 'DitCoin Token',
            'DIW' => 'DIW Token',
            'DKK' => 'Danish Krone',
            'DLT' => 'Delta',
            'DMND' => 'DIAMOND',
            'DMT' => 'DMarket Token',
            'DMTS' => 'DMTS',
            'DNC' => 'DinarCoin',
            'DNET' => 'DeNet',
            'DNET2' => 'DNeT Token',
            'DNL' => 'Donocle',
            'DNT' => 'Dante Token',
            'DNT2' => 'district0x Network Token',
            'DOCK' => 'DockToken',
            'DOG' => 'DOG: The Anti-Scam Reward Token',
            'DOGE' => 'Dogecoin',
            'DOGE.BEP20' => 'Dogecoin (BSC Chain)',
            'DOGEX' => 'DogeX',
            'DOGEX2' => 'DOGEX',
            'DOPT' => 'Dystopia Tokens',
            'DOR' => 'DoradoToken',
            'DOS' => 'DOS Token',
            'DOT.BEP20' => 'Polkadot Token (BSC Chain)',
            'DPN' => 'DIPNET',
            'DPSC' => 'DPSChain',
            'DPST' => 'DPSChain token',
            'DPT' => 'DeepToken',
            'DRCT' => 'DRC Token',
            'DREAM' => 'DreamTeam Token',
            'DRG' => 'DRAGON',
            'DRGN' => 'Dragon',
            'Drink' => 'DrinkChain',
            'DRN' => 'DRONECOIN',
            'DRONE' => 'DEEP AERO',
            'DROP' => 'Dropil',
            'DSCB' => 'DataShieldCoinBank',
            'DSN' => 'Dsion',
            'DSPX' => 'SP8DE PreSale Token',
            'DSQ' => 'DASHQ',
            'DST' => 'Decentralize Silver Token',
            'DT' => 'DragonToken',
            'DTA' => 'Data Token',
            'DTC' => 'DateCoin ICO Token',
            'DTK' => 'Drive Token',
            'DTRC' => 'Datarius Credit',
            'DUCAT' => 'Ducat',
            'DUSK' => 'Dusk Network',
            'DWS' => 'DWS',
            'DXCASH' => 'DXCASH',
            'DXG' => 'Dexage',
            'DYDX' => 'dYdX',
            'DYP' => 'DeFiYieldProtocol',
            'DYT' => 'DoYourTip',
            'E2C' => 'Electronic Energy Coin',
            'EAI' => 'ethereumAI Token',
            'EAR' => 'EAR',
            'EASY' => 'EASY',
            'EAT' => 'EquityAlert',
            'EBC' => 'EBCoin',
            'eBCC' => 'eBitcoinCash',
            'EBK' => 'Ebakus',
            'EBNB' => 'EBNB',
            'EBTC' => 'eBTC',
            'EBYTE' => 'Etherball',
            'EC' => 'EU coin',
            'ECASH' => 'ethereumcash',
            'ECHG' => 'ECHARGE',
            'ECO' => 'Eco',
            'ECO2' => 'EcoPoint',
            'ECO3' => 'ECO',
            'ECOM' => 'ECOM',
            'ECOMT' => 'E-Commerce Token',
            'ECP' => 'ECP Token',
            'ECPN' => 'ECPN Token',
            'ECT' => 'SuperEdge',
            'ECTE' => 'EurocoinToken',
            'EDOGE' => 'EtherDoge',
            'EDT' => 'EDT',
            'EDU' => 'Education',
            'EEE' => 'Elementh Token',
            'EER' => 'EthereumeRush',
            'EES' => 'Super Energy',
            'EET' => 'ETHERCToken',
            'EFFM' => 'EFFM',
            'EFI' => 'EFI Token',
            'EGC' => 'ElgalCoin',
            'EGC2' => 'Exchange Global Crypto',
            'EGG' => 'Egg Token',
            'EGT' => 'EnjoyGameToken',
            'EGT2' => 'Egretia',
            'EKT' => 'EDUCare',
            'EKT2' => 'EKT',
            'ELEC' => 'ElectrifyAsia',
            'ELI' => 'EligmaToken',
            'ELON' => 'Dogelon',
            'ELT' => 'ETH Light',
            'ELTC' => 'eLTC',
            'ELTX' => 'ELTOSX Token',
            'ELV' => 'Elsevier',
            'ELYTE' => 'Ethereum Lyte',
            'EMAN' => 'EMAN Token',
            'eMax' => 'EthereumMax',
            'Emoji' => 'EmojiToken',
            'EMONA' => 'EtheremonMonster',
            'EMONT' => 'EtheremonToken',
            'EMPR' => 'empowr',
            'EMPRB' => 'empowr blue',
            'EMT' => 'ElectronicMusic',
            'ENAU' => 'eNAU',
            'ENC' => 'Ethernet Cash',
            'ENCX' => 'Encrybit',
            'ENG' => 'Enigma',
            'ENJ' => 'Enjin Coin',
            'ENK' => 'Enkidu',
            'ENTRY' => 'Entry Token',
            'ENTS' => 'EUNOMIA',
            'ENU' => 'Enumivo',
            'EO' => 'EO Coin',
            'EON' => 'Entertainment Open Network',
            'EON2' => 'EOS Network',
            'EOSBNT' => 'EOS Smart Token Relay',
            'EOSC' => 'EOS CLASSIC',
            'eosDAC' => 'eosDAC',
            'EOSG' => 'EOS GOLD',
            'EOST' => 'EasyEosToken',
            'EOST2' => 'EOS TRUST',
            'EOT' => 'EOT',
            'EPAY' => 'EPay',
            'EPC' => 'Etherplanet',
            'EPCO' => 'EtherPlus Coin',
            'EPH' => 'Euphoria',
            'EPL' => 'Ethereum Platinum',
            'EPLAYG' => 'EplayGold',
            'ePRX' => 'eProxy',
            'EPY' => 'EmphyCoin',
            'EQL' => 'EQUAL',
            'ERC20' => 'ERC20',
            'ERCMO' => 'ERCmoney',
            'ESAX' => 'ESAX Token',
            'ESHIP' => 'EliteShipperToken',
            'ESS' => 'ESSENTIA',
            'ET' => 'Eacx Token',
            'ETC' => 'Ether Classic',
            'ETC.BEP20' => 'Ethereum Classic (BSC Chain)',
            'ETCR' => 'EtherCare',
            'ETD' => 'EtherDiamond',
            'ETD2' => 'EtherDiamond',
            'ETG' => 'EthereumGoldToken',
            'ETGP' => 'Ethereum Gold Project',
            'ETH' => 'Ether',
            'ETH.BEP20' => 'Ethereum Token (BSC Chain)',
            'ETH3' => 'Ethereum',
            'ETH4' => 'Ethereum',
            'ETHAI' => 'Ethereum AI',
            'ETHB' => 'ETHERBTC',
            'ETHBNT' => 'BNT Smart Token Relay',
            'ETHC' => 'EthereumCash',
            'ETHC2' => 'EtherCat',
            'ETHC3' => 'Ethereum Crystal',
            'ETHER' => 'ETHERLANCE',
            'ETHM' => 'Ethereum Meta',
            'ETHMNY' => 'Ethereum Money',
            'ETHPLO' => 'ETHplode',
            'ETHS' => 'EtherStone',
            'ETHUC' => 'Ethereum Uranium',
            'ETHV' => 'Ethverse Token',
            'ETHV2' => 'Ethereum Vault',
            'ETM' => 'Ethermoney',
            'ETOS' => 'Ether EOS',
            'ETR' => 'Ethereum Red',
            'ETS' => 'ETROS',
            'ETU' => 'Ether Universe',
            'ETWT' => 'Etherwave',
            'ETY' => 'Ethereum Cloud',
            'EUCX' => 'EUCX Token',
            'EURB' => 'EUROBITS',
            'EURT' => 'Tether EUR (ERC20)',
            'EVA' => 'EVA',
            'EVEO' => 'EVEOToken',
            'EVERY.ERC20' => 'Everyworld (ERC20)',
            'EVN' => 'Envion',
            'EVN2' => 'EvenCoin',
            'EVY' => 'EveryCoin',
            'EXAC' => 'Extra Box Cash',
            'EXC' => 'Exceed',
            'EXMR' => 'EXMR',
            'EXNX' => 'Exenox Mobile',
            'EXPO' => 'Online Expo',
            'EXTRA' => 'ExTrade Cash',
            'EYC' => 'EveryCoin',
            'F2K' => 'Farm2Kitchen Token',
            'FABA' => 'FABA',
            'FACC' => 'FOR Agriculture Coin',
            'FACE' => 'Faceter Token',
            'FACTS' => 'FACTS Token',
            'FAIR' => 'Fair Token',
            'FANZ' => 'FanChain',
            'FBC' => 'Fortune Blockchain',
            'FBN' => 'FiveBalance',
            'FBTC' => 'Fastbitcoin',
            'FCC' => 'FinCrypChain',
            'FDUSD.BEP20' => 'First Digital USD (BSC Chain)',
            'FDUSD.ERC20' => 'First Digital USD (ERC20)',
            'FDZ' => 'Friendz Coin',
            'FET' => 'Fetch',
            'FET.Old' => 'Fetch (Old Contract)',
            'FEX' => 'FeniXCoin',
            'FEY' => 'Feyorra',
            'FF' => 'flashflip',
            'FFF' => 'FFF News',
            'FGP' => 'FingerPrint',
            'FilmC' => 'FilmChain',
            'FIRO' => 'Firo',
            'FISH' => 'Fishbank',
            'FIT' => 'FINANCIAL INVESTMENT TOKEN',
            'FKX' => 'Knoxstertoken',
            'FKX2' => 'Knoxstertoken',
            'FLETA' => 'Fleta Token',
            'FLIX' => 'FLIX Token',
            'FLOT' => 'Fire Lotto',
            'FLP' => 'FLIP Token',
            'FLT2' => 'Flit Token',
            'FLX' => 'BitFlux',
            'FLX2' => 'Flixze',
            'FND' => 'FundRequest',
            'FNDZ.BEP20' => 'FNDZ Token (BSC Chain)',
            'FNK' => 'Finiko',
            'FNKOS' => 'FNKOSToken',
            'FNKOS2' => 'FNKOSToken',
            'FNTC' => 'Fantasy Sports Coin',
            'FOOD' => 'FoodCoin',
            'FOR' => 'The Force Token',
            'FORTH' => 'Ampleforth Governance',
            'FOTA' => 'FOTA',
            'FOX' => 'FOX',
            'FOXT' => 'Fox Trading',
            'FPT' => 'Finple Token',
            'FREC' => 'Freyr Coin',
            'FREN.BEP20' => 'Frenchie (BSC Chain)',
            'FRES' => 'FRESCO',
            'FRIKANDEL' => 'Frikandel',
            'FT' => 'Fabric Token',
            'FT1' => 'Fleshy Tender ONE',
            'FTEC' => 'FTEC',
            'FTG' => 'fantomGO',
            'FTI' => 'FTI',
            'FTM' => 'Fantom Token (ERC20)',
            'FTN' => 'Fasttoken (ERC20)',
            'FTN.BAHAMUT' => 'Fasttoken (Bahamut)',
            'FTT' => 'FTX Token',
            'FTXT' => 'FUTURAX',
            'FUD' => 'DimonCoin',
            'FUN' => 'FunFair',
            'FUND' => 'FUND',
            'FUNDZ' => 'FundToken',
            'FUZE' => 'FUZE Token',
            'FX' => 'Function X',
            'FXBK' => 'FX Buy Back',
            'FXC' => 'FUTURAX',
            'FXET' => 'EthereumFox',
            'FXP' => 'FXPay',
            'FXT' => 'FXtrading',
            'FXY' => 'FIXY NETWORK',
            'FYS' => 'Fysical',
            'G' => 'GoldCoin Cash',
            'G4B' => 'Game4Bitcoin',
            'G4D' => 'Give4Dream',
            'g9tro' => 'g9tro Crowdfunding Platform',
            'GAE' => 'GAE NETWORK',
            'GALA' => 'Gala (ERC20)',
            'GALA.Old' => 'Gala (ERC20) (Old Contract)',
            'GANA' => 'GANA',
            'GARD' => 'HASHGARD',
            'GAZPROM' => 'Gazprom Coin',
            'GBC' => 'Gold Bits Coin',
            'GBK' => 'Goldblock',
            'GBP' => 'British Pound',
            'GBP2' => 'GBHub Pro',
            'GBT' => 'GBT',
            'GBT2' => 'GBT2',
            'GBX' => 'Globitex Token',
            'GC' => 'GalaxyCoin',
            'GCASH' => 'G-CASH',
            'GCB' => 'GCB',
            'GCB2' => 'Golden Coin Blockchain',
            'GCC3D' => 'Global 3D Currency',
            'GCG' => 'Global Crypto Gate',
            'GCG.Old' => 'Global Crypto Gate',
            'GCG.Old2' => 'Global Crypto Gate',
            'GCS' => 'Gamechain System',
            'GCU' => 'Global Currency Unit',
            'GDE' => 'DigitalEnthusiasts',
            'GDP' => 'GrossDomesticProduct',
            'GDPR' => 'GDPR Cash',
            'GEF' => 'Global Environment Fund',
            'GEL' => 'Georgian Lari',
            'GELDC' => 'GELDCoin',
            'GEM' => 'Gems',
            'GENE' => 'GENE TOKEN (PARKGENE)',
            'GENT' => 'Genesis',
            'GES' => 'Game Engine Chain',
            'GET' => 'GET',
            'GETX' => 'Guaranteed Ethurance Token Extra',
            'GEX' => 'GexCrypto',
            'GFL' => 'Golden Fleece',
            'GFN' => 'GameFanz',
            'GFT' => 'GiftToken',
            'GFUN' => 'GoldFund',
            'GG' => 'Geo Gems',
            'GGL' => 'Google Token',
            'GHC.Old.BEP20' => 'Galaxy Heroes Coin (Old) (BSC Chain)',
            'GHS' => 'GHS',
            'GHX' => 'GamerCoin',
            'gif' => 'GifCoin',
            'GIFT' => 'GIFTTOKEN',
            'GIP' => 'Gibraltar Pound',
            'GLARB' => 'Glarbs',
            'GLM' => 'Golem Network Token',
            'GLO' => 'Globo Token',
            'GLX2' => 'Golix Token',
            'GMB' => 'GMB',
            'GMEE' => 'GAMEE',
            'GMET' => 'GME Technology',
            'GMV' => 'Green Movement',
            'GNC' => 'Greencoin',
            'GNCT' => 'GN Compass',
            'GNT' => 'Golem (Old Chain)',
            'GNX' => 'Genaro X',
            'GOB' => 'GOB Token',
            'GOD' => 'Goold on Deck',
            'GODZ' => 'GODZILLION',
            'GOEX' => 'GOEX Token',
            'GOLD' => 'GoldenChain',
            'GOLD2' => 'GoldChain',
            'GOLD3' => 'GOLD',
            'Googol' => 'Networth',
            'GOOLA' => 'Goola token',
            'GOT' => 'Gold Token',
            'GOT2' => 'GOeureka',
            'GoTJS' => 'GoT Jon Snow',
            'GPaid' => 'GetPaid',
            'GPaid2' => 'GetPaid Token',
            'GPN' => 'GPN Coin',
            'GPT' => 'GoPower Token',
            'GR' => 'GameRoot Token',
            'GR2' => 'GROM',
            'GRAM' => 'Gram',
            'GRT' => 'Graph Token',
            'GRX' => 'Gold Reward Token',
            'GSC' => 'Global Social Chain',
            'GSE' => 'GSENetwork',
            'GSGC' => 'GSG coin',
            'GST' => 'GAMESTARS TOKEN',
            'GTO' => 'Gifto',
            'GTX' => 'GoalTime N',
            'GUNTHY' => 'GUNTHY',
            'GUP' => 'Guppy',
            'GUSD' => 'Gemini dollar',
            'GVC.BEP20' => 'Global Virtual Coin (BSC Chain)',
            'GVE' => 'Globalvillage ecosystem',
            'GVINE' => 'GVINE',
            'GVT' => 'Genesis Vision Token',
            'GWT' => 'GetWeed',
            'GXC' => 'Game X Coin',
            'HAE' => 'HAENP',
            'HAND' => 'ShowHand',
            'HANDY' => 'Handy Token',
            'HART' => 'HaraToken',
            'HAV' => 'Havven',
            'HBZ' => 'Helbiz Token',
            'HC' => 'Hotcoin',
            'Hcoin' => 'Hcoin Token',
            'HDA' => 'Honda Chain',
            'HDC' => 'Harvardcoin',
            'HEC' => 'HeroCoin',
            'HEC2' => 'Hermes Edu Coin',
            'HELP' => 'HELP4HUMANITY',
            'HER' => 'HeroNodeToken',
            'HERB' => 'Herbalist Token',
            'HERO' => 'Hero Origen Token',
            'HETA' => 'HetaToken',
            'HEX' => 'HEX',
            'HEX2T' => 'HEX2T',
            'HGO' => 'HireGo',
            'HGT' => 'HelloGold Token',
            'HIBT' => 'HiBTCToken',
            'HINT' => 'Hint',
            'HIT' => 'HitchainCoin',
            'HKDex' => 'NEEX Hong Kong Dollar',
            'HKY' => 'HKY Token',
            'HLI' => 'Hooli Coin Blockchain',
            'HLOS' => 'HLOS',
            'HLS' => 'Helios Token',
            'HMB' => 'HaMeBi',
            'HMC' => 'Hms Token',
            'HOT' => 'Hydro Protocol Token',
            'HOT2' => 'HoloToken',
            'HOTC' => 'HOTchain',
            'HOUSE' => 'HOUSE',
            'HPC' => 'Hash Power Token',
            'HPS' => 'Hyper Play Shares',
            'HQX' => 'HOQU Token',
            'HRK' => 'Croatian Kuna',
            'HRT' => 'HighRise',
            'HSB' => 'HashByte',
            'HSC' => 'HashCoin',
            'HSHC' => 'Hash Card',
            'HT' => 'HuobiToken',
            'HTX' => 'Hashtrust',
            'HTX2' => 'Huptex',
            'HUF' => 'Hungarian Forint',
            'HUP' => 'HUPAYX',
            'HUR' => 'Hurify Token',
            'HUSD' => 'HUSD',
            'HVC' => 'Horex Coin',
            'HVE' => 'UHIVE',
            'HXRO' => 'Hxro',
            'HXY' => 'HEX Money',
            'HYBN' => 'Hey Bitcoin',
            'HYDRO' => 'Hydro',
            'HYDRO2' => 'Hydro',
            'HYPE' => 'Hyper Token',
            'i' => 'ICOTH',
            'I9C' => 'I9Coin',
            'IAG' => 'Iagon',
            'IBA' => 'iBuildApp Network Token',
            'IBA2' => 'Invictus Bitcoin Alpha (IBA)',
            'IBTC' => 'IBTC',
            'IBTC2' => 'IBTC',
            'iCash' => 'iCash Token',
            'ICC' => 'Intelligent Commerce Chain',
            'iCSH' => 'iCASH',
            'ICST' => 'Individual Content & Skill Token',
            'ICTA' => 'ICTA',
            'IDEX' => 'IDEX Token',
            'IDH' => 'indaHash Coin',
            'IDK' => 'IDKToken',
            'IDN' => 'Indonesian Project',
            'IDR' => 'Indonesian Rupiah',
            'IDRT' => 'Rupiah Token',
            'IDXE' => 'Index Empire',
            'ieos' => 'ieo services',
            'IEX' => 'International Exchange',
            'IEXC20' => 'Ion Exchange Token',
            'iFish' => 'iFishYunYu',
            'IFOOD' => 'Ifoods Token',
            'IFT' => 'Feed',
            'IG' => 'IG',
            'IGNT' => 'IGNITE',
            'IGTMYR' => 'International Gaming Token MYR',
            'IHT' => 'I HOUSE TOKEN',
            'IIC' => '智投链',
            'ILS' => 'Israeli Shekel',
            'ILT' => 'illume',
            'IMC' => 'imchain',
            'IMDX' => 'Imdex',
            'IMOS' => 'Intelligent Manufacturing Operation System',
            'IMP' => 'Ether Kingdoms Token',
            'IMT' => 'MoneyToken',
            'IMVR' => 'ImmVRse Token',
            'IND' => 'Indorse Token',
            'INEX' => 'Internet Exchange Token',
            'INGAME' => 'IN GAME CREDIT',
            'INGRAM' => 'INGRAM',
            'INK' => 'INK token',
            'INN' => 'AirBnbChain',
            'INNBC' => 'InnovativeBioresearchCoin',
            'INNBCL' => 'InnovativeBioresearchClassic',
            'INR' => 'Indian Rupee',
            'INRex' => 'NEEX Indian Rupee',
            'INS' => 'INS Token',
            'INS2' => 'Infinity Network Solutions',
            'INSTAR' => 'Insights Network',
            'INSUR' => 'InsurChain Coin',
            'INT' => 'Intelion',
            'INVITE' => 'Invite Token',
            'INVOX' => 'Invox Finance Token',
            'IONC' => 'IONChain Token',
            'IOST' => 'IOSToken',
            'IOT5' => 'Internet of Things 5th-Generation',
            'IOTA.BEP20' => 'MIOTAC (BSC Chain)',
            'IOTX' => 'IoTeX Network',
            'IOUX' => 'IOU Loyalty Exchange Token',
            'IOV' => 'CarLive Chain',
            'IPSX' => 'IPSX',
            'IPUX' => 'IPUX Token',
            'IRR' => 'Iranian Rial',
            'IRT' => 'Iranian Toman',
            'IRX' => 'IronX',
            'ISK' => 'Icelandic Krona',
            'ISLM.EVM' => 'Islamic Coin (Haqq) EVM',
            'IST' => 'iShop Token',
            'ITC' => 'IOT on Chain',
            'ITCB' => 'itCoin® Black',
            'IUT' => 'ITO Utility Token',
            'IVO' => 'IvoToken',
            'IVY' => 'IvyKoin Public Network Tokens',
            'IWC' => 'InfinityWinCoin',
            'IZER' => 'IZEROIUM',
            'IZER2' => 'IZEROIUM',
            'IZI' => 'IZIChain',
            'IZX' => 'IZX Token',
            'J8T' => 'J8T Token',
            'JAR' => 'Jarvis+ Coins',
            'JASMY.ERC20' => 'JasmyCoin (ERC20)',
            'JBX' => 'Jbox',
            'JC' => 'Jesus Coin',
            'JDT' => 'Jungle Coin',
            'JE' => 'Jonvi Exchange',
            'JEX' => 'JEX Token',
            'JOB' => 'Jobchain',
            'JPY' => 'Japanese Yen',
            'JPYC' => 'JPY Coin',
            'JSE' => 'JSE Token',
            'JST.TRC20' => 'JUST GOV v1.0 (Tron/TRC20)',
            'JURM' => 'Juriseum',
            'K4W' => 'Key4Win',
            'KBC' => 'KaratBank Coin',
            'KBC2' => 'KaratBank Coin',
            'KCH' => 'KahnChat',
            'KCS.Old' => 'KuCoin Shares',
            'KEA' => 'KEA Coin',
            'KEOS' => 'KEOSToken',
            'KES' => 'Kenyan Shilling',
            'KEY' => 'SelfKey',
            'KEYS' => 'SignkeysToken',
            'KGT' => 'KamaGames Token',
            'KGW' => 'Kawanggawa',
            'KHC' => 'KHCoin',
            'KHP' => 'Kheper',
            'KINBNT' => 'KIN Smart Token Relay',
            'KIND' => 'Kind Ads Token',
            'KIT' => 'KitToken',
            'KITTEN' => 'Kitten Coin',
            'KLT' => 'KELTA',
            'KMX' => 'KIMEX',
            'KNC' => 'Kyber Network Crystal',
            'KNCL' => 'Kyber Network Crystal (Old)',
            'KNDC' => 'KanadeCoin',
            'KNO' => 'Knocknock',
            'KNOW' => 'KNOW',
            'KNT' => 'Kamen Token',
            'KOK' => 'KOK Coin',
            'KPNG' => 'KEPENG',
            'KPR' => 'KPR Coin',
            'KRC' => 'Kurecoin',
            'KRC2' => 'Kurecoin Token',
            'KREX' => 'Kronn',
            'KRI' => 'KriosCoin',
            'KRL' => 'Kryll',
            'KRW' => 'South Korean Won',
            'KRYP' => 'Kryptonium',
            'KSC' => 'KStarCoin',
            'KSG' => 'KINGS GLOBAL',
            'KSS' => 'Krosscoin',
            'KTC' => 'KEEPTokenCoin',
            'KTD' => 'Kotlind',
            'KTT' => 'K-Tune Token',
            'KUE' => 'Kuende Token',
            'KUR' => 'KURCHAIN TOKEN',
            'KWATT' => 'KWATT COIN',
            'KYO' => 'KayoCredits',
            'LAK' => 'Laotian Kip',
            'LAKE' => 'Wiktor Jezioro Token',
            'LAMB' => 'Lambda',
            'LAMBO' => 'LamboCoin',
            'LAMBO2' => 'LAMBORGHINI',
            'LAToken' => 'LAToken',
            'LATX' => 'LatiumX',
            'LBA' => 'LibraToken',
            'LBA2' => 'LightBitAtom',
            'LBOT' => 'LegalBot',
            'LC' => 'Love Chain',
            'LCD' => 'Lucyd',
            'LCK' => 'LuckCash',
            'LCMS' => 'LCMS',
            'LDC' => 'LEADCOIN',
            'LDN' => 'LydianCoin',
            'LEASH' => 'DOGE KILLER',
            'LEEK' => 'Leek coin',
            'LEF' => 'lightning exchange finance',
            'LEND' => 'EthLend Token',
            'LEON' => 'Leonardian',
            'LET' => 'LinkEye Token',
            'LEXC' => 'LEX Coin',
            'LEXT' => 'LEXT',
            'LFT' => 'Linfinity',
            'LGBTQ' => 'Pride',
            'LGCY' => 'LGCY Network',
            'LGR' => 'Logarithm',
            'LGUM' => 'Ledgerium',
            'LHC' => 'LHCoin',
            'Libfx' => 'Libfx',
            'Libfx2' => 'Libfx',
            'LIFE' => 'PureLifeCoin',
            'LINK' => 'ChainLink Token (ERC20)',
            'LINK.BEP20' => 'ChainLink Token (BSC Chain)',
            'LINO' => 'LinoToken',
            'LION' => 'LION',
            'LIPS' => 'Lipchain',
            'LIQUID' => 'Netkoin Liquid',
            'LIT' => 'Litentry',
            'LK' => 'LIKER',
            'LKSC' => 'LKSCOIN',
            'LMDA' => 'LaMonedaCoin',
            'LNC' => 'Lancer Token',
            'LOC' => 'LockChain',
            'LON' => 'Tokenlon',
            'LOOIX' => 'LOOiX',
            'LOOIX2' => 'LOOIX',
            'LOT' => 'LotteryToken',
            'LOTO' => 'Lotoblock',
            'LOVC' => 'Love Wine Coin',
            'LPC' => 'Little Phil Coin',
            'LRC' => 'LoopringCoin V2',
            'LST' => 'Lendroid Support Token',
            'LT' => 'Loctite Assets Token',
            'LTB' => 'Litbinex Coin',
            'LTC2' => 'Litetoken',
            'LTCD' => 'LitecoinDiamond',
            'LTCP' => 'Litecoin Private',
            'LTK' => 'Litecoin Token',
            'LUC' => 'Level-Up Coin',
            'LUNA' => 'Wrapped LUNA Token',
            'LXT' => 'LiteXToken',
            'LYKK' => 'Lykk REAL',
            'LYNDA' => 'LyndaCoin',
            'LYNK' => 'LynKey',
            'LYQD' => 'GlobaLiquids',
            'LYS' => 'LIGHTYEARS',
            'M10' => 'M10 Fan Club',
            'MAC' => 'Matrexcoin',
            'MAD' => 'Moroccan Dirham',
            'MAID' => 'MaidSafeCoin',
            'MAPR' => 'Maya Preferred 223',
            'MASP' => 'MaspToken',
            'MAYA' => 'Maya Coin',
            'MB' => 'MonsterBit',
            'MBCH' => 'MILLIONBITCOINCASH',
            'MBN' => 'Membrana',
            'MBTC' => 'Minibitcoin',
            'MBYZ' => 'MBYZ Coin',
            'MCAP' => 'MCAP',
            'MCASH' => 'Mennet Cash',
            'MCC' => 'MyCreditChain',
            'McFLY' => 'McFlyToken',
            'MCG' => 'MCGCoin',
            'MCO' => 'Monaco',
            'MDCM' => 'MDCMCoin',
            'MDK' => 'MDKToken',
            'MDM' => 'MADAMA TOKEN',
            'MDR' => 'Modorr',
            'MDTK' => 'MD Tokens',
            'MEDA' => 'Medanio',
            'MEDAL' => 'Medallion',
            'MEDIBIT' => 'MEDIBIT',
            'MEDS' => 'MEDSToken',
            'MEME' => 'MEMEZ',
            'MEQ' => 'Meterqubes',
            'MEREX' => 'Merexchange',
            'MESH' => 'MeshBox',
            'METH' => 'Mostaza Ethereum',
            'mETH2' => 'Mini Ethereum',
            'METM' => 'MetaMorph',
            'MFT' => 'Mainframe Token',
            'MGC' => 'More Gold Coin',
            'MIB' => 'Mobile Integrated Blockchain',
            'MIC' => 'Mindexcoin',
            'MILE' => 'SnagRide',
            'MILO' => 'MILO',
            'MINAX' => 'MinaxCoin',
            'MINDS' => 'Minds',
            'MINEX' => 'MINEX',
            'MINIDOGE.BEP20' => 'MiniDOGE (BSC Chain)',
            'MINX' => 'InnovaMinex',
            'MIO' => 'MinerOne',
            'MIT' => 'Mychatcoin',
            'MITx' => 'Morpheus Infrastructure Token',
            'MK' => 'Mankind',
            'MKC' => 'MKC Token',
            'MKCN' => 'Mkoin',
            'MKD' => 'Macedonian Denar',
            'MKF' => 'Mankind First',
            'MMT' => 'Maximum Token',
            'MNDE.SOL' => 'Marinade (Solana)',
            'MNE2' => 'Minereum',
            'MNE3' => 'Minereum',
            'MNET' => 'Mine Network Token',
            'MOAS' => 'Mortify Asset',
            'MOAT' => 'MOAT',
            'MOC' => 'Moss Coin',
            'MOF' => 'Molecular Future',
            'MOLK' => 'Mobilink Token',
            'MOLK2' => 'MobilinkToken',
            'MOR' => 'MoriaToken',
            'MOR2' => 'MorCrypto Coin 2',
            'MORE' => 'MORE',
            'MORPH' => 'MORPH',
            'MOT' => 'MOT',
            'MPAX' => 'MPax Coin',
            'MPAX2' => 'MPAX Coin',
            'MPU' => 'MPFSC',
            'MPX' => 'MPAX Coin',
            'MRG' => 'WemergeToken',
            'MRK' => 'Mark',
            'MRL' => 'Marcelo',
            'MRN' => 'Marine',
            'MRO' => 'Mero Currency',
            'MRP' => 'MrpToken',
            'MRS' => 'Marginless Token',
            'MRS2' => 'Marginless Token',
            'MSB' => 'Magic E-Stock',
            'MSB2' => 'Magic E-Stock',
            'MSC' => 'MSCToken',
            'MSD' => 'MSD',
            'MSG' => 'BitMessage',
            'MSH' => 'MayaShares',
            'MSIA' => 'Gourmet chain',
            'MSOL.SOL' => 'Marinade Staked SOL (Solana)',
            'MST' => 'MarketSpaceToken',
            'MST2' => '民宿通',
            'MT' => 'MT Token',
            'MTC' => 'MTCoin',
            'MTCX2' => 'MythicX',
            'MTH' => 'Monetha',
            'MUNE' => 'Mune Token',
            'MUR' => 'Mauritian Rupee',
            'MUSE' => 'Muse',
            'MUSK' => 'Musk Token',
            'MUST' => 'Main Universal Standard of Tokenization',
            'MVG' => 'Max',
            'MVL' => 'Mass Vehicle Ledger Token',
            'MVP' => 'Merculet',
            'MVR' => 'Mavro Token',
            'MWAVS' => 'Massive WAVs',
            'MXM' => 'Maximine Coin',
            'MXM2' => 'Maximine Coin',
            'MXN' => 'Mexican Peso',
            'MXNT' => 'MXNTUNOAUNO',
            'MYBET' => 'MyBetterCoin',
            'MyDFS' => 'MyDFS Token',
            'MYEX' => 'Maya Exchange',
            'MYOU' => 'MYOUToken',
            'MYR' => 'Malaysian Ringgit',
            'MYT' => 'MeYou Token',
            'MZG' => 'MZI GOLD',
            'NACRE' => 'Nacreous',
            'NAM' => 'Nam Coin',
            'NAMTT' => 'NamTanToken',
            'NANJ' => 'NANJCOIN',
            'NANOCOIN' => 'Nano Coin',
            'NAT' => 'Natmin',
            'NAVI' => 'BoatPilot Token',
            'NAVI2' => 'NaviToken',
            'NBAT' => 'NobelAcme',
            'NBC' => 'Niobium',
            'NBT2' => 'Ninsa B Token',
            'NBT3' => 'NiceBytes',
            'NC' => 'NewChat',
            'nCash' => 'NucleusVision',
            'NCL' => 'Nuclear Platform',
            'NDX' => 'nDEX',
            'NEAL' => 'Coineal Token',
            'NEE' => 'NEENOTE',
            'NEEO' => 'NEEO',
            'NEOD' => 'NEODiamond',
            'NEON' => 'NeonCoin',
            'NESC' => 'Nebula Exchange Token',
            'NETH' => 'Nodoka ETH',
            'NEWOS' => 'NewOS Token',
            'NEXO' => 'Nexo',
            'NEYROS' => 'Neyros Network',
            'NFC' => 'Ninfinance',
            'NGC' => 'NAGA Coin',
            'NGN' => 'Nigerian Naira',
            'NGOT' => 'NGOT',
            'NICASH' => 'Nicash',
            'NIRX' => 'Naira X Token',
            'NKN' => 'NKN',
            'NLC' => 'NovaLend',
            'NLC3' => 'NLC Token',
            'NLS' => 'Neluns',
            'NMP' => 'Neuromorphic',
            'NMR' => 'Numeraire',
            'NMX' => 'Numex',
            'NN' => 'Neodium Network',
            'NOAH' => 'NOAHCOIN',
            'NOAHP' => 'NOAH DECENTRALIZED STATE COIN',
            'NOBS' => 'No BS Crypto',
            'NOK' => 'Norwegian Krone',
            'NOMO' => 'Bitnomo',
            'NOVI' => 'Libra',
            'NOW' => 'ChangeNOW',
            'NOX' => 'Nitro',
            'NPLAYG' => 'NplayGold',
            'NPT' => 'Nova Planet Token',
            'NPXC' => 'Pundi X Classic',
            'NPXS' => 'Pundi X Token',
            'NQN' => 'NuQoin',
            'NRM' => 'Neuromachine Eternal',
            'NRN' => 'Neuron',
            'NRP' => 'Neural Protocol',
            'NST' => 'NewSolution',
            'NSUR.BEP20' => 'NSUR (BSC Chain)',
            'Nsure' => 'Nsure Network Token',
            'NTC' => 'Nextcoin',
            'NTICP' => 'Nitecoinpay',
            'NTK' => 'Netkoin',
            'NTK2' => 'NeuroToken',
            'NTN' => 'Neutron',
            'NTOK' => 'NTOK Token Contract',
            'NTWK' => 'Network Token',
            'NTX' => 'NatureX',
            'NUG' => 'Nuggets',
            'NULS' => 'Nuls',
            'NULS.BEP20' => 'Nuls (BSC Chain)',
            'NUMEX' => 'Numex',
            'NVT' => 'NVTNetworkToken',
            'NYBC' => 'NYBCoin',
            'O2O' => 'O2O',
            'OAK' => 'Acorn Collective Token',
            'OAP' => 'Open Alexa Protocol',
            'OAS' => 'OASES',
            'OAX' => 'openANX Token',
            'OBX' => 'OBXCoin',
            'OBXP' => 'OBXPetro',
            'OCC' => 'Original Crypto Coin',
            'OCN' => 'OCoin',
            'OCT' => 'Open Chain Stocks',
            'OD' => 'Origin D',
            'ODC' => 'ODDO Coin',
            'ODEM' => 'ODEM Token',
            'ODMC' => 'ODMCoin',
            'OGOD' => 'OGOD',
            'OHNI' => 'ohni_2',
            'Ohni2' => 'Ohni',
            'OHTANI' => 'OHTANICOIN',
            'OICOIN' => 'Osmium Investment Coin',
            'OKM' => 'OKMcoin',
            'OKO' => 'OKOIN',
            'OLE' => 'Olive',
            'OMG' => 'OmiseGo',
            'OMNES' => 'Omnes Coin',
            'OMNI' => 'Omni',
            'OMX' => 'Omix',
            'ONE' => 'BigONE Token',
            'ONG' => 'onG',
            'ONP' => 'Oracle Network Protocol',
            'ONSTON' => 'ONSTON',
            'OnUp' => 'OnUp TOKEN',
            'OPCT' => 'Opacity',
            'OPEN' => 'OPEN',
            'OPENC' => 'OPEN Chain',
            'OPET' => 'Opet Coin Token',
            'OPET2' => 'Opet Token',
            'OPQ' => 'Opacity',
            'OPS' => 'OPS',
            'OPT' => 'OPTin Token',
            'OPTC' => 'OPTICAL NETWORK',
            'ORIC' => 'ORICToken',
            'ORME' => 'Ormeus Coin',
            'ORN' => 'Orion Protocol',
            'ORO' => 'ORO Token',
            'OSC' => 'OasisCity',
            'OSCH' => 'OpenSourceChain Token',
            'OSHI' => 'MyIdolCoin',
            'OTB' => 'OctaBlock',
            'OTN' => 'Open Trading Network',
            'OUCHI' => 'OUCHI Token',
            'OUT' => 'OutCloud',
            'OVF' => 'Orius Venture Foundation',
            'OVO' => 'ICOVO',
            'OWD' => 'Owlstand',
            'OWL' => 'OWL Token',
            'OXI' => 'OXI',
            'OXT' => 'Orchid',
            'OXY' => 'OXY',
            'P2PG' => 'P2PGuru',
            'PAI' => 'PCHAIN',
            'PAID' => 'PaidThru',
            'PAL' => 'PolicyPal Network Token',
            'Panda.BEP20' => 'Panda Chain (BSC Chain)',
            'PAR' => 'Parachute',
            'PAT' => 'PATRON',
            'PAX' => 'PAX',
            'PAX2' => 'Paxos Standard',
            'PAXG' => 'Paxos Gold',
            'PAY' => 'TenX Pay Token',
            'PAYA' => 'PAYA',
            'PAYA2' => 'PAYA',
            'PAYIN' => 'Payin Token',
            'PBTT' => 'Purple Butterfly Token (PBTT)',
            'PCH' => 'PlugCoinCash',
            'PCT' => 'Perkscoin',
            'PDC' => 'Project Decorum Coin',
            'PEAK' => 'PEAKDEFI',
            'PEF' => 'PEFToken',
            'PEN' => 'Peruvian Sol',
            'PERL' => 'Perlin',
            'PERU' => 'PeruCoin',
            'PETRO' => 'Petroleum',
            'PEW' => 'BroFistCoin',
            'PEX' => 'pokerbox',
            'PGC' => 'Paygine',
            'PGC2' => 'PIGCOIN',
            'PHI' => 'PHI Token',
            'PHM' => 'Phoneum',
            'PHN' => 'Phillionex',
            'PHNX' => 'PhoenixDAO',
            'Phone' => 'Phone',
            'PHP' => 'Philippines Peso',
            'PHPex' => 'NEEX PESO PHILIPPINE',
            'PHRM' => 'Pharmeum',
            'PHT' => 'Phoneum Token',
            'PHX' => 'PHANUX',
            'PIB' => 'Pibble Token',
            'PICKLE' => 'PickleToken',
            'PIGGY' => 'Piggies',
            'PIT' => 'Paypite v2',
            'PIVX' => 'PIVX',
            'PIX' => 'PIX Token',
            'PKG' => 'PKG Token',
            'PKR' => 'Pakistani Rupee',
            'PLA' => 'PlayChip',
            'PLA2' => 'PLA Token',
            'PLAAS' => 'PLAAS FARMERS TOKEN',
            'PLAT' => 'BitGuild PLAT',
            'PLN' => 'Polska Zloty',
            'PLR' => 'PILLAR',
            'PLS' => 'PLAAS',
            'PLU' => 'Pluton',
            'PLUS' => 'plus token',
            'PM7' => 'PM7',
            'PMA' => 'PumaPay',
            'PMC' => 'Primebank Coin',
            'PMNT' => 'Paymon Token',
            'PMUP' => 'Pump Up The Coin',
            'PNK' => 'Pinakion',
            'PNT' => 'Penta Network Token',
            'POA20' => 'POA20 (ERC20 Token)',
            'POABNT' => 'POA Smart Token Relay',
            'POK' => 'Poker IO',
            'POL' => 'Polygon (formerly MATIC) (Polygon Chain)',
            'POL.BEP20' => 'Polygon (formerly MATIC) Token (BSC Chain)',
            'POL.ERC20' => 'Polygon (formerly MATIC) (ERC20)',
            'POL.Old.ERC20' => 'Polygon (formerly MATIC) (Old Contract) (ERC20)',
            'POLY' => 'Polymath',
            'PONA' => 'Ponder Airdrop Token',
            'PONAIR' => 'Ponder Airdrop Token',
            'POPCOIN' => 'PopCoin',
            'PORT' => 'Port Network',
            'POSS' => 'Posscoin',
            'POT2' => 'Pointex Token',
            'POTA' => 'POTATO',
            'POTE' => 'Optec',
            'POWR' => 'PowerLedger',
            'PPD' => 'PingPaid',
            'PPDX' => 'Plus Protocol',
            'PPP' => 'PayPie',
            'PPS' => 'PopulStay Token',
            'PPT' => 'Populous Platform',
            'PPTK' => 'PREPAID',
            'PRE' => 'Premine',
            'PRE2' => 'Presearch',
            'PRF' => 'PROOF',
            'PRIX' => 'Privatix',
            'PRL' => 'Oyster Pearl',
            'PRN' => 'Proteania',
            'PRO' => 'ProChain',
            'PRO2' => 'Propy',
            'PROD' => 'ProducToken',
            'PRSMD' => 'PresiamDrop',
            'PSYP.BEP20' => 'PolkaSyndicate Plus (BSC Chain)',
            'PT2' => 'Peace Token',
            'PTK' => 'Pot Token',
            'PTNX' => 'Platin Token',
            'PTT' => 'Proton Token',
            'PTYS' => 'PanaStar',
            'PUN' => 'Punch Token',
            'PUNDIX' => 'Pundi X Token',
            'PVT' => 'Pivot Token',
            'PVU.BEP20' => 'Plant vs Undead Token (BSC Chain)',
            'PWV' => 'Peoplewave Token',
            'PXC' => 'PixieCoin',
            'PXE' => 'Pixie Token',
            'PXG' => 'PlayGame',
            'PXLT' => 'Pixel Crowdsale Token',
            'PXP' => 'PIGGYPILE',
            'PXP2' => 'PointPay Token',
            'PXP3' => 'PointPay Crypto Banking Token V2',
            'PYE.BEP20' => 'CREAMPYE (BSC Chain) (Old)',
            'PYN' => 'Paycentos Token',
            'PYR' => 'PYR Token',
            'PYUSD.ERC20' => 'PayPal USD (ERC20)',
            'PYX' => 'PriorityEx',
            'QAU' => 'Quantum',
            'QBE' => 'Qubicle',
            'Qbs' => 'Qbbss',
            'QBT' => 'QBT',
            'QDA' => 'Quadrant Assets',
            'QDT' => 'Quantfury Data Token',
            'QPAY' => 'QuantumPay',
            'QRP' => 'Cryptics ERC20 Token',
            'QSP' => 'Quantstamp Token',
            'QTF' => 'Quantfury Token',
            'QTUM' => 'Qtum',
            'QUBT' => 'Cubechain',
            'QUIN' => 'QUINADS',
            'R' => 'R token',
            'RADAR' => 'DappRadar',
            'RAKU' => 'RAKUN',
            'RALLY' => 'Rally Coin',
            'RAM' => 'Retail and Merchant Token',
            'RAMEN' => 'RamenCoin',
            'RAYAX' => 'RAYAX',
            'RBDN' => 'Robust Malware Defense',
            'RBLX' => 'Rublix',
            'RBTC' => 'RobotCoin',
            'RBTC2' => 'Rebitcoin',
            'RBX' => 'Rubiix Token',
            'RCN' => 'Ripio Credit Network Token',
            'RDN' => 'Raiden Token',
            'RDX' => 'Redux token',
            'REBL' => 'Rebellious',
            'REBLC' => 'REBEL COIN',
            'REDRA' => 'RedRabbitToken',
            'REDV' => 'Redvolution',
            'REF' => 'RefToken',
            'REG' => 'Retengo',
            'REKT' => 'REKT',
            'REOS' => 'REOS',
            'REP' => 'Reputation',
            'REQ' => 'Request Token',
            'REX' => 'inerexToken',
            'RFE' => 'RICH FOR EVER',
            'RFR' => 'Refereum',
            'RFX' => 'Reflex',
            'RGB' => 'Clocks',
            'RGLS' => 'Regulus Token',
            'RGT' => 'Retail Global Token',
            'RIC' => 'AURIcoin',
            'RIDE' => 'RideNode',
            'RIDE2' => 'RideToken',
            'RIG' => 'Rich Gold Token',
            'RIPT' => 'RiptideCoin',
            'RIS' => 'RisingCoin',
            'RISE.BEP20.Old' => 'EverRise (BSC Chain Old)',
            'RISK' => 'Global Risk Exchange Token',
            'RITZ.BEP20' => 'RITZ (BSC Chain)',
            'RKT' => 'Rock Token',
            'RNDR' => 'Render Token',
            'RNT' => 'OneRoot Network Token',
            'RNTB' => 'RNTB Token',
            'ROBO' => 'CryptoRobotics',
            'ROCK' => 'Rocket Token',
            'ROCK2' => 'ICE ROCK MINING',
            'Rock2Pay' => 'Rock2Pay',
            'ROK' => 'Rockets',
            'RON' => 'Romanian Leu',
            'ROTA' => 'ROTA',
            'ROTA2' => 'ROTA',
            'RPC' => 'Ripio Coin',
            'RPCN1' => 'ROPCOIN',
            'RPL' => 'Rocket Pool Protocol',
            'RTB' => 'AB-CHAIN RTB token',
            'RTGS' => 'Digital Zimbabwe',
            'RTH2' => 'Rethen Token',
            'RUB' => 'Russian Ruble',
            'RUSH' => 'TokenRush',
            'RVN' => 'Ravencoin',
            'RWF' => 'Rwandan Franc',
            'RXE' => 'RealXoin',
            'RXL' => 'RxEAL',
            'RYD' => 'Rydberg',
            'S' => 'Sharpay',
            'S39.BEP20' => 'S39 Token (BSC Chain)',
            'S3C' => 'S3 COIN',
            'SAC' => 'Smart Application Chain',
            'SAFEBTC.BEP20' => 'SafeBTC (BSC Chain)',
            'SAFU' => 'SAFU COIN',
            'SAITAMA' => 'Saitama Inu',
            'SALT' => 'Salt',
            'SAM' => 'Samfins',
            'SANC' => 'Sancoj',
            'SAND' => 'SAND',
            'SAT' => 'Social Activity Token',
            'SATAN' => 'CryptoSatan',
            'SATO' => 'Satoshi',
            'SATT' => 'Smart Advertising Transaction Token',
            'SATX' => 'SatoExchange',
            'SAVE' => 'SaveToken',
            'SBA' => 'simplyBrand Token',
            'SCB' => 'ShiftCashExtraBonus',
            'SCC' => 'StockChain Coin',
            'SCC2' => 'SiaCashCoin',
            'SCCTN' => 'SmartCityCoinTestNet',
            'SCD' => 'Sharing Currency',
            'SCH' => 'Sachio',
            'SCT' => 'Soma Community Token',
            'SCT2' => 'SatoshiCrypto',
            'SCX' => 'Swachhcoin',
            'SDA' => 'Six Domain Asset',
            'SDC' => 'Singapore Dollar Coin',
            'SDFT' => 'SDF Token',
            'SEC' => 'SEC',
            'SEC2' => 'Insurance',
            'SEER' => 'SEER-ERC20-Token',
            'SEHR' => 'SecuredEHR',
            'SEK' => 'Swedish Krona',
            'SENX' => 'SensusNetwork',
            'SERENITY' => 'SERENITY',
            'SETH' => 'Sether',
            'SETI' => 'South East Trading Investment',
            'SETI2' => 'South East Trading Investment',
            'SEXC' => 'ShareX',
            'SEYU' => 'SeiyuuCoin',
            'SFP.BEP20' => 'SafePal Token (BSC Chain)',
            'SFU' => 'Saifu',
            'SG' => 'SocialGood',
            'SGC' => 'SuponicGameCoin',
            'SGCC' => 'SGCC',
            'SGDex' => 'NEEX Singapore Dollar',
            'SGN' => 'Signals Network Token',
            'SGP' => 'SGPay Token',
            'SHAB.BEP20' => 'Sharpei (BSC Chain)',
            'SHAG' => 'Shaggy Coin',
            'SHEEP' => 'Sheep Coin',
            'SHEL' => 'shelterDAO',
            'SHIB' => 'SHIBA INU (ERC20)',
            'SHIB.BEP20' => 'SHIBA INU (BSC Chain)',
            'SHINJA' => 'Shibnobi',
            'SHIP' => 'ShipChain SHIP',
            'SHIT' => 'ShitCoin',
            'SHL' => 'Oyster Shell',
            'SHOP' => 'ShoppingCoin',
            'SHPC' => 'ShoppingCoin',
            'SHPING' => 'Shping Coin',
            'SHR' => 'ShareToken',
            'SIG' => 'Signals',
            'SIM' => 'Simmitri',
            'SINGH' => 'SinghCoin',
            'SKE' => 'Super Keep Token',
            'SKI' => 'Skillchain',
            'SKL' => 'SKALE',
            'SKRP' => 'Skraps',
            'SKYFT' => 'SKYFchain',
            'SKYM' => 'Skymap',
            'SLD' => 'Solid Sources Token',
            'SLK' => 'Silk',
            'SLRM' => 'Solareum',
            'SLT' => 'SLT',
            'SLV' => 'The Silverlink Network Token',
            'SMART2' => 'Ethereum Smart',
            'SMG' => 'SMG (BSC Chain)',
            'SMT' => 'SmartMesh Token',
            'SMT2' => 'Smathium',
            'SMT3' => 'Silhouette',
            'SNBL.Old' => 'Snowball',
            'SNcoin' => 'scientificcoin',
            'SNGLS' => 'SingularDTV',
            'SNGX' => 'SingularX',
            'SNL' => 'Sport AND Leisure',
            'SNT' => 'StatusNetwork',
            'SNT2' => 'Status Network Token',
            'SNTR' => 'Silent Notary Token',
            'SNTVT' => 'Sentivate',
            'SNX' => 'Synthetix Network Token',
            'Soar' => 'Soarcoin',
            'SOL' => 'Solana',
            'SOL.BEP20' => 'SOLANA (BSC Chain)',
            'SOL2' => 'Sola Token',
            'SOLAMA.SOL' => 'Solama (Solana)',
            'SOP' => 'SoPay',
            'SOUL' => 'CryptoSoul',
            'SOUND' => 'Sound',
            'Soundeon' => 'Soundeon Token',
            'SOV' => 'Sovrin',
            'SPANK' => 'SPANK',
            'SPARC' => 'Science Power and Research Coin',
            'SPAZ' => 'Swapcoinz',
            'SPAZ.Old' => 'SWAPCOINZ',
            'SPB' => 'Superblue',
            'SPD' => 'SPINDLE',
            'SPECT' => 'Spectraal',
            'SPH' => 'Sapphire Coin',
            'SPH2' => 'Spheroid',
            'SPIZ' => 'Space-iz Token',
            'SPON' => 'Instant Sponsor',
            'SPS' => 'SP Coin',
            'SPS2' => 'SURPRISE',
            'SPX' => 'SP8DE Token',
            'SPZ' => 'SwapCoinz',
            'SPZ.Old' => 'SWAPCOINZ',
            'SQR' => 'Squeezer',
            'SRK.BEP20' => 'SparkPoint (BSC Chain)',
            'SRNT' => 'Serenity',
            'SRX' => 'Soraix',
            'SSP' => 'smartshare token',
            'STAC' => 'StarterCoin',
            'STAMP' => 'STAMP',
            'STASH' => 'BitStash',
            'STASH2' => 'BitStash',
            'STATIZ' => 'Statiz',
            'STCDR' => 'STCDR',
            'STDEX' => 'stableDEX',
            'STE' => 'STeX Exchange ICO',
            'STER' => 'Airdropster',
            'STG' => 'StargateToken',
            'STH' => 'Super Ethereum',
            'stish' => 'Stish',
            'STM' => 'Streamity',
            'STM.Old' => 'Streamity',
            'STMI.BEP20' => 'STAKEMINE (BSC Chain)',
            'STMX' => 'Crypterio Coin',
            'STMX2' => 'StormX',
            'STO' => 'storeum',
            'STORM' => 'Storm Token',
            'STPZ' => 'CodeMailStamp',
            'STQ' => 'Storiqa Token',
            'STR2' => 'Strategic Token',
            'STRONG' => 'Strong',
            'STS' => 'Status Security',
            'STT' => 'Synthestech Token',
            'STY' => 'Styras',
            'SUN' => 'SUNCOIN',
            'SUPR' => 'SupeRare',
            'SURE' => 'SURETY Token',
            'SURE2' => 'inSure',
            'SUSHI' => 'SushiToken',
            'SW' => 'Super Wallet Token',
            'SWAMP.BEP20' => 'Swampy (BSC Chain)',
            'SWC' => 'Sky Win Chain',
            'SWFTC' => 'SwftCoin',
            'SXE' => 'Scalpex Token',
            'SXL' => 'SuccessLife',
            'SXS' => 'SPECTRE SUBSCRIBER TOKEN',
            'SYS' => 'Syscoin',
            'SZC' => 'Zugacoin',
            'T8T' => 'T8T Coin',
            'TAB' => 'Accounting Blockchain Token',
            'TAC' => 'Traceability Chain Coin',
            'TAI' => 'Turing AI',
            'TAL' => 'Thaler',
            'TAPS' => 'TAPSPAY',
            'TAS' => 'TAS Token',
            'TAXC' => 'TAXICOIN',
            'TB' => 'TimeBox Coin',
            'TBCoin' => 'TokenBookCoin',
            'TBFC' => 'the bfc',
            'TBL' => 'Tombola',
            'TBT' => 'TBT',
            'TBT2' => 'The Best Token',
            'TBTC' => 'tBTC',
            'TBTC.Tidbit' => 'Tidbit Coin',
            'TCA' => 'TangguoTao Token',
            'TCASH' => 'Tcash',
            'TCAT' => 'TheCurrencyAnalytics',
            'TCH' => 'ThoreCash',
            'TCL' => 'Techshare Token (TCL)',
            'TCR' => 'TecraCoin',
            'TCT' => 'TokenClub Token',
            'TDH' => 'Trustedhealth',
            'TDP' => 'TrueDeck',
            'TEAM' => 'TEAM',
            'TEL.Old' => 'Telcoin (Old Chain)',
            'TELE' => 'MiracleTele',
            'TEP' => 'Tepleton',
            'TERI' => 'TengRi Cash Coin',
            'TERN' => 'Ternio (ERC20)',
            'TET' => 'Tetcoin',
            'TEU' => '20-footEqvUnit',
            'TEUR' => 'BTEUR',
            'TFD' => 'TE-FOOD',
            'TGC' => 'Time Game Coin',
            'TGCO' => 'Thaler Group Company',
            'TGT' => 'Twogap Token',
            'THB' => 'Thai Baht',
            'THL' => 'THLToken',
            'THL2' => 'THALER',
            'THM' => 'Themis Token',
            'THR' => 'ThoreCoin',
            'THRN' => 'ThornCoin',
            'THUG' => 'THUG LIFE Coin',
            'THX' => 'ThoreNext',
            'TIDAL' => 'Tidal Token',
            'TIKTOK' => 'TIKTOK COIN',
            'TILY' => 'Instantily',
            'TIO' => 'TradeToken',
            'TIP' => 'Tip Token',
            'TIR' => 'Truxir',
            'TIS' => 'TREESTAR',
            'TIX' => 'Lottery Tickets',
            'TKA' => 'TokiaToken',
            'TKLN' => 'Taklimakan',
            'TKN' => 'TokenCard',
            'TKT' => 'CryptoTickets COIN',
            'TLB' => 'The Luxury Coin',
            'TLC' => 'TravelCoin',
            'TLC2' => 'TheLegendCoin',
            'TLC3' => 'Tilcoin',
            'TLW' => 'TILWIKI - Faces of Art',
            'TMB' => 'TemboCoin',
            'TMC' => 'Tumin',
            'TND' => 'Tunisian Dinar',
            'TNT' => 'Tierion Network Token',
            'TOE' => 'Theone',
            'TOKO' => 'Tokoin',
            'TOMA' => 'TokenMasternode',
            'TON.BEP20' => 'Wrapped TON Coin (BSC Chain)',
            'TON.ERC20' => 'Wrapped TON Coin (ERC20)',
            'TONE' => 'TE-FOOD/TustChain',
            'TOPB' => 'TOPBTC TOKEN',
            'TOPBTC' => 'TOPBTC',
            'TOPG' => 'TopGnetwork',
            'TOS' => 'ThingsOpreatingSystem',
            'TOS2' => 'KRATOS',
            'TOTO' => 'TouristToken',
            'TOU' => 'TOURISTOKEN',
            'TQN' => 'Toqqn',
            'TRA' => 'TRA',
            'TRADE' => 'Smart Trade Coin',
            'TRAK' => 'TrakInvest Token',
            'TRAT' => 'Tratin',
            'TRAVEL' => 'TRAVEL Token',
            'TRF' => 'Trifolium Coin',
            'TRG' => 'Triggmine Coin',
            'TRIM' => 'Trilliam',
            'TRIO' => 'Tripio Token',
            'TRIX' => 'TriumphX',
            'TRIX.TrixChain' => 'TRIXCHAIN',
            'TRM' => 'TRMToken',
            'TRM2' => 'TerraMiner',
            'TRON' => 'Bitcoin Tron',
            'TRST' => 'Trustcoin',
            'TruAu' => 'TruAu',
            'TRV' => 'TRUVA',
            'TRX' => 'TRON',
            'TRX.BEP20' => 'TRON (BSC Chain)',
            'TRX.ERC20' => 'Tronix (Old ERC-20)',
            'TRX.OLD.BEP20' => 'TRON (Old Contract) (BSC Chain)',
            'TRXC' => 'TRONCLASSIC',
            'TRY' => 'Turkish Lira',
            'TSHP' => '12Ships',
            'TT.BEP20' => 'Tdex Token (BSC Chain)',
            'TTC' => 'TTC',
            'TTC2' => 'TheTimesChain Coin',
            'TTKN' => 'TheToken',
            'TTT' => 'Tapcoin',
            'TTV' => 'Token for Television',
            'TUSD' => 'TrueUSD',
            'TUSD.BEP20' => 'TrueUSD (BSC Chain)',
            'TUSD.BEP20.Old' => 'TrueUSD (BSC Chain) (Old Contract)',
            'TUSD.PRC20' => 'TrueUSD (Polygon)',
            'TUSD.TRC20' => 'TrueUSD (Tron/TRC20)',
            'TUSD2' => 'TrueUSD',
            'TVT' => 'TVT',
            'TVT2' => 'TVT',
            'TWC' => 'TheWebCoin',
            'TWETH' => 'Thunder Wrapped ETH',
            'TWNKL' => 'Twinkle',
            'TWT' => 'TwitCOIN',
            'TWT.BEP20' => 'Trust Wallet (BSC Chain)',
            'TXC' => 'TenXcoin',
            'TXT' => 'Trextoken',
            'TXT2' => 'TXT',
            'TXT3' => 'Tune Trade Token',
            'TXTE' => 'TrexExchange Token',
            'TXY' => 'Telomere Coin',
            'TYPE' => 'Typerium',
            'UAH' => 'Ukrainian Hryvnia',
            'UBC' => 'UBCoin',
            'UBEX' => 'UBEX Token',
            'UBIT' => 'Ubit Cash',
            'UBN' => 'Ubricoin',
            'UC' => 'YouLive Coin',
            'UCASH' => 'UCASH',
            'UCN' => 'UChain Token',
            'UCT' => 'UCOT',
            'UEC' => 'United Emirate Coin',
            'UFAN8' => 'UFAN8',
            'UFT' => 'UniLend Finance Token',
            'UGC' => 'UG Coin',
            'UIP' => 'UnlimitedIP Token',
            'UKG' => 'UnikoinGold',
            'UKR' => 'UKR Chain',
            'ULLU' => 'ullu',
            'ULT' => 'Ultiledger',
            'ULTRA' => 'Ultrachain',
            'UMA' => 'UMA Voting Token v1',
            'UMT' => 'Universal Mobile Token',
            'UNB' => 'United Bull Traders',
            'UNC' => 'UniCoin',
            'UNI.BEP20' => 'Uniswap (BSC Chain)',
            'UNI.ERC20' => 'Uniswap (ERC20)',
            'UNIA' => 'uniaswap',
            'UNIO' => 'UNIO',
            'UNIT2' => 'UNIVERSE TOKEN',
            'UNQT' => 'Unique Utility Token',
            'UNV' => 'UniversalCoin',
            'UOK' => 'YouOK Coin',
            'UOS' => 'Ultra Token',
            'UPBTC' => 'Universal Bitcoin',
            'UPP' => 'SENTINEL PROTOCOL',
            'UPUSD' => 'Universal US Dollar',
            'UPXAU' => 'Universal Gold',
            'UQn' => 'Uqinzen',
            'URUN' => 'URUN',
            'USAT' => 'USAT Inc',
            'USD1' => 'Psyche',
            'USD2' => 'USD',
            'USDC' => 'USD Coin (ERC20)',
            'USDC.BEP20' => 'USD Coin (BSC Chain)',
            'USDC.E.PRC20' => 'USDC.e (Bridged USDC) (Polygon/MATIC)',
            'USDC.PRC20' => 'USD Coin (Polygon/MATIC)',
            'USDC.SOL' => 'USD Coin (Solana)',
            'USDC.TRC20' => 'USD Coin (Tron/TRC20)',
            'USDex' => 'NEEX USD',
            'USDEX2' => 'eToro United States Dollar',
            'USDK' => 'USDK',
            'USDN' => 'Neutrino USD',
            'USDS' => 'StableUSD',
            'USDS2' => 'Stable USD',
            'USDT' => 'Tether USD (Omni Layer)',
            'USDT.BEP20' => 'Tether USD (BSC Chain)',
            'USDT.ERC20' => 'Tether USD (ERC20)',
            'USDT.PRC20' => 'Tether USD (Polygon/MATIC)',
            'USDT.SOL' => 'Tether USD (Solana)',
            'USDT.TRC20' => 'Tether USD (Tron/TRC20)',
            'USDTETHER' => 'USDTether',
            'USDX' => 'USDX',
            'USE' => 'UseChain Token',
            'USEC' => 'US Ecosystem',
            'UST.Old' => 'Uservice Token',
            'UST2' => 'UseChainToken',
            'USTC.BEP20' => 'Wrapped UST Token (BSC Chain)',
            'USTC.ERC20' => 'Wrapped USTC Token',
            'UTK' => 'Utrust Token',
            'UTK.Old' => 'UTRUST Token',
            'UTNP' => 'UTN-P: Universa Token',
            'UTO' => 'UTour',
            'UUNIO' => 'UUNIO Token',
            'VALOR' => 'ValorToken',
            'VALUE' => 'Value Liquidity',
            'VALUE2' => 'VALUE',
            'VB' => 'VBToken',
            'Vcash' => 'Vcash',
            'VCCN' => 'VCcoin',
            'VCT' => 'ValueCyberToken',
            'VD' => 'Bitcoin Card',
            'VDH' => 'VDH Token',
            'VDV.BEP20' => 'VIRVIA ONLINE SHOPPING (BSC Chain)',
            'VEN' => 'VeChain Token (ERC20)',
            'VERS' => 'Verus',
            'VES' => 'VESTELLA',
            'VEST' => 'Vestchain',
            'VETH' => 'Vital  Ethereum',
            'VFA' => 'VoferCC',
            'VGB' => 'VGB',
            'VGS' => 'VGAMES',
            'VGX' => 'Voyager Token',
            'VIB' => 'Vibe',
            'VIBE' => 'Vibe Coin',
            'VICO' => 'VICO Vote Token',
            'VIDB' => 'VNDC International Digital Banking',
            'VIDY' => 'VidyCoin',
            'VIEW' => 'Multiview',
            'VIN' => 'VIN',
            'VINX' => 'VINX COINS STO',
            'VIO' => 'Vio',
            'VIP' => 'VIP',
            'VIRIDI' => 'ViRiDi',
            'VIU' => 'VIU',
            'VIX' => 'VianeX',
            'VLC' => 'Value Chain',
            'VLTR' => 'VULTUR',
            'VLX.BEP20' => 'Velas (BSC Chain)',
            'VLXPAD.BEP20' => 'VELASPAD.io (BSC Chain)',
            'VLXPAD.ERC20' => 'VELASPAD.io (ERC20)',
            'VME' => 'Verime Mobile',
            'VND' => 'Vietnamese Dong',
            'VNDC' => 'VNDC',
            'VNDC.BEP20' => 'VNDC (BSC Chain)',
            'VNDex' => 'NEEX Vietnam Dong',
            'VNM' => 'VENOM',
            'VNS' => 'VenusToken',
            'VOW' => 'Vow',
            'VPP' => 'Value Promise Protocol token',
            'VQR' => 'Virtual Quantum Reality',
            'VRA' => 'VERA',
            'VRS' => 'Veros',
            'VRT' => 'ViralToken',
            'VRT.BEP20' => 'Venus Reward Token (BSC Chain)',
            'VS' => 'ValuesShare',
            'VSO' => 'TOKENVESTTO',
            'VST' => 'Vestarin',
            'VT' => 'VectoraicToken',
            'VT2' => 'VectoraicToken',
            'VTA' => 'Vita Token',
            'VTCH' => 'vertcoin cash',
            'VTR' => 'VTrust',
            'VTY' => 'VerityToken',
            'VVC' => 'VELVET COIN',
            'VVI' => 'VV Coin',
            'VXD' => 'Velix ID Token',
            'VXNT' => 'Vixen Token',
            'VXRC' => 'Vexareum Cash',
            'VYA' => 'VAYLA Token',
            'W0xETH' => 'Wrapped 0xEthereum Token',
            'W12' => 'W12 Token',
            'W2TW' => 'WatertoWorld',
            'W3C' => 'W3C',
            'WAB' => 'WABnetwork',
            'WAR' => 'WAR Token',
            'WBNB' => 'Wrapped BNB (Wormhole)',
            'WBNB.BEP20' => 'Wrapped BNB (BSC Chain)',
            'WBT' => 'WhalesburgToken',
            'WBTC' => 'Wrapped BTC',
            'wDOGE.BEP20' => 'wDogecoin (BSC Chain)',
            'WDT' => 'WEED TOKEN',
            'WEB' => 'Webcoin',
            'WEBN' => 'WEBN',
            'WEL' => 'Welcome Coin',
            'WELL' => 'WELL Token',
            'WETH' => 'Wrapped Ether',
            'WETH.PRC20' => 'Wrapped Ether (Polygon/MATIC)',
            'WFEE' => 'WFee',
            'WGC' => 'wegen',
            'WGT' => 'WorldGamingTech',
            'WIKEN' => 'ProjectWITH',
            'WIN' => 'WCOIN',
            'WIN.BEP20' => 'WINk (BSC Chain)',
            'WIN2' => 'WINSTEX',
            'WIN3' => 'WinCoin',
            'WIT' => 'WIT',
            'WITH' => 'WITH coin',
            'WKC' => 'WANKCOIN',
            'WLM' => 'Win Last Mile',
            'WMCH' => 'WeMediaCash',
            'WMK' => 'WemarkToken',
            'WNK' => 'Woonk',
            'WNS' => 'WINSSHI',
            'WOLF' => 'WiseWolf',
            'WOM.Old' => 'WOM Token (Old Token)',
            'WOO' => 'Wootrade Network',
            'WOOL' => 'woolchain',
            'Woonk' => 'Woonkly',
            'WOT' => 'WOTChain',
            'WOZX' => 'EFFORCE IEO',
            'WPR' => 'WePower Token',
            'WRC' => 'Worldcore',
            'WS' => 'WisdomStock',
            'WSE' => 'WhiteSwap',
            'WSS' => 'ETHWSS Coin',
            'WT' => 'WeToken',
            'WTC' => 'Walton Token',
            'WTE' => 'WITEE',
            'WTL' => 'Welltrado token',
            'WTP' => 'Web token Pay',
            'WTS' => 'WALLETOURS',
            'WXRP' => 'Wrapped XRP',
            'WZI' => 'Wizzle Infinity Token',
            'XAG' => 'Silver (Troy Ounce)',
            'XAP' => 'Appics',
            'XAU' => 'Gold (Troy Ounce)',
            'XAUR' => 'Xaurum',
            'XAUT' => 'Tether Gold (ERC20)',
            'XBANC' => 'XBANC',
            'XBP' => 'BlitzPredict',
            'XBR' => 'BIT DINERO',
            'XCEL' => 'XCELTOKEN',
            'XCLR' => 'ClearCoin',
            'XCON' => 'Connect coin(XCON)',
            'XCT' => 'XChain Token',
            'XCZ' => 'XCOYNZ Token',
            'XDAC' => 'XDAC COIN',
            'XDMC' => 'XDMC token',
            'XEM' => 'NEM',
            'XEMX' => 'Xeniumx',
            'XEN' => 'XENIACOIN',
            'XFRC' => 'Fructus',
            'XI' => 'XI Network',
            'XIN' => 'Mixin',
            'XLAB' => 'XCELTOKEN PLUS',
            'XLC' => 'Ethereum Lite Cash',
            'XMC' => 'MingoCoin',
            'XMCT' => 'XMED Chain Token',
            'XMD' => 'Monero Diamond',
            'XMOO' => 'MOO token',
            'XMR' => 'Monero',
            'XMRG' => 'Monero Gold',
            'XMX' => 'XMAX',
            'XNK' => 'Ink Protocol',
            'XNN' => 'XENON',
            'XOF' => 'West African CFA Franc',
            'XPR' => 'PolarisToken',
            'XPR2' => 'Proton',
            'XPS' => 'Payshares',
            'XPT' => 'Paytokens',
            'XPU' => 'Polaris Universal',
            'XRA' => 'MasterXriba',
            'XRB' => 'Rainbow',
            'XRM' => 'Aerum',
            'XRP' => 'XRP (XRPL)',
            'XRP.BEP20' => 'XRP Token (BSC Chain)',
            'XRPC' => 'XRP CLASSIC',
            'XRR' => 'Xchangerate Coin',
            'XRT' => 'XRT Token',
            'XRT2' => 'XRT Token',
            'XSAP' => 'XSAPPHIRE',
            'XSP' => 'SpaikCoin',
            'XT' => 'XstarToken',
            'Xtera' => 'XTerato',
            'XTRLPay' => 'XTRLPay',
            'XTX' => 'XtockToken',
            'XVG' => 'VERGE',
            'XVT' => 'Vantage Token',
            'XYO' => 'XY Oracle',
            'YAH' => 'JamaiCoin',
            'YANU' => 'Yanu',
            'YAP' => 'Yaapoo',
            'YCC' => 'Yuan Chain New',
            'YD' => 'YouDeal Token',
            'YEE' => 'Yee - A Blockchain-powered & Cloud-based Social Ecosystem',
            'YES' => 'On-Chain Verification',
            'YESM' => 'YesManCoin',
            'YFIM' => 'Yearn Finance Money',
            'YFIN' => 'YFIN',
            'YOO' => 'Yooba token',
            'YSN' => 'ySignToken',
            'YUSDT' => 'Yellow Tether',
            'YZC' => 'YoozCoin',
            'ZAG' => 'ZAG Token',
            'ZAR' => 'South African Rand',
            'ZB' => 'ZBToken',
            'ZBK' => 'ZBANK',
            'ZBK2' => 'ZBANK',
            'ZCN' => '0chain',
            'ZDR' => 'Zloadr Token',
            'ZDR2' => 'Zloadr Token',
            'ZEC' => 'ZCash',
            'ZEEW' => 'ZEEW',
            'ZEN' => 'Horizen',
            'ZENIQ' => 'ZENIQ',
            'ZENIQ2' => 'ZENIQ',
            'ZENIQ3' => 'ZENIQ',
            'ZERO' => 'ZEROCoin',
            'ZEWT' => 'ZEWT',
            'ZFL' => 'Zuflo Coin',
            'ZIG' => 'Ziggurat Token',
            'ZIL' => 'Zilliqa',
            'ZING' => 'Zing Token',
            'ZIP' => 'Zipper',
            'ZJLT' => 'ZJLT Distributed Factoring Network',
            'ZKS' => 'Zks',
            'ZLA' => 'Zilla Token',
            'ZNT' => 'Zenswap Network Token',
            'ZOM' => 'ZOM',
            'ZPR' => 'ZperToken',
            'ZRX' => '0x Protocol Token',
            'ZSC' => 'Zeus Shield Coin',
            'ZTX' => 'Zulu Republic Token',
            'ZXC' => '0xcert Protocol Token',
            'ZYTH.BEP20' => 'UZYTH (BSC Chain)',
            'BTC.Bitstamp' => 'Bitstamp BTC',
            'CAD.Bluzelle' => 'Bluzelle CAD',
            'EUR.Bitstamp' => 'Bitstamp EUR',
            'GBP.Bitstamp' => 'Bitstamp GBP',
            'USD.Bitstamp' => 'Bitstamp USD',
            'LTCT' => 'Litecoin Testnet',
          );
    }


}